const AWS = require('aws-sdk');
const consts = require('../../utils/consts');
const getCredentials = require('../cloud-manager/credentials-operations');
const getLogger = require('../../utils/logger');
const { setProxy } = require('../cloud-manager/config-operations');

const logger = getLogger();

AWS.config.logger = {
    log: line => logger.debug(line)
};

async function getEC2() {
    logger.debug('Getting EC2');

    const credentials = await getCredentials(consts.AWS);
    const httpOptions = await setProxy(consts.AWS);

    return new AWS.EC2({
        credentials, region: consts.DEFAULT_AWS_REGION, httpOptions
    });
}

async function getAwsRegions() {
    logger.info('Getting AWS regions');
    const ec2 = await getEC2();
    const regions = await ec2.describeRegions().promise();

    return regions.Regions.map(region => region.RegionName);
}

module.exports = getAwsRegions;
