const { Subscriptions, SubscriptionClient } = require('@azure/arm-subscriptions');
const getCredentials = require('../cloud-manager/credentials-operations');
const { getConfigIdentity } = require('../cloud-manager/config-operations');
const { setProxy } = require('../cloud-manager/config-operations');
const getLogger = require('../../utils/logger');
const { AZURE } = require('../../utils/consts');

const logger = getLogger();

async function getSubscriptions() {
    logger.debug('Getting subscriptions');
    const credentials = await getCredentials(AZURE);
    await setProxy(AZURE);
    const client = new SubscriptionClient(credentials);

    return new Subscriptions(client);
}

async function listSubscriptions() {
    logger.info('Listing subscriptions');
    const subscriptions = await getSubscriptions();

    return subscriptions.list();
}

async function listLocations() {
    logger.info('Listing locations');
    const subscriptions = await getSubscriptions();
    const { subscription } = await getConfigIdentity();

    return subscriptions.listLocations(subscription);
}

module.exports = {
    listSubscriptions,
    listLocations
};
