const { Storage } = require('@google-cloud/storage');
const { GCP } = require('../../utils/consts');
const { setProxy } = require('../cloud-manager/config-operations');
const getLogger = require('../../utils/logger');

const logger = getLogger();
const storage = new Storage();

async function createBucket(bucketName, location, storageClass = 'standard') {
    logger.info('Creating GCP bucket:', { bucketName, location, storageClass });
    // storage can be created wih a specific storageClass
    await setProxy(GCP);
    const [bucket] = await storage.createBucket(bucketName, { location, storageClass });

    return {
        name: bucket.metadata.name,
        region: bucket.metadata.location.toLowerCase(),
        storageClass: bucket.metadata.storageClass.toLowerCase()
    };
}

async function getBuckets() {
    logger.info('Getting GCP buckets');
    await setProxy(GCP);
    const [buckets] = await storage.getBuckets();

    return buckets.map(bucket => {
        const { metadata: { name, location, storageClass } } = bucket;
        return { name, region: location.toLowerCase(), storageClass: storageClass.toLowerCase() };
    });
}

async function setStorageClass(bucketName, storageClass) {
    logger.info('Setting GCP bucket storage class:', { bucketName, storageClass });
    await setProxy(GCP);
    const bucket = storage.bucket(bucketName);

    await bucket.setStorageClass(storageClass);
}

module.exports = { createBucket, getBuckets, setStorageClass };
