const {
    get, cloneDeep
} = require('lodash');
const { auditRecordSchema } = require('../validation/audit-schemas');
const { validateSchema } = require('../utils/schema-validation');
const gotInstance = require('../utils/got');
const getLogger = require('../utils/logger');
const hideSecretsHelper = require('../utils/hide-secrets');

const logger = getLogger();

const OCCM_URL = 'http://cloudmanager_audit:80/audit';
const CT_SERVICE_NAME = 'cloud-tiering';

async function sendAuditRecord(request, reply, isStart, payload) {
    try {
        // get status and error message
        let status;
        let errorMessage;
        if (isStart) {
            status = 'pending';
        } else {
            status = 'success';
            // trying to see if there's any error in payload
            if (payload && (typeof (payload) === 'string')) {
                try {
                    const payloadObj = JSON.parse(payload);
                    if (payload && payloadObj.error) {
                        status = 'failed';
                        errorMessage = payloadObj.message || 'unknown error';
                    }
                } catch (err) {
                    logger.warn('Couldn\'t figure out if there\'s error in payload', err, 'sending status - success');
                }
            }
        }

        // build object
        const auditRecord = {
            recordId: parseInt(request.headers['x-request-id'], 10),
            actionName: get(reply, 'context.schema.description', 'unknown'),
            date: Date.now(),
            status,
            requestId: request.headers['x-service-request-id'],
            serviceName: CT_SERVICE_NAME,
            errorMessage
        };
        const clonedData = cloneDeep(request.body);
        const hiddenData = hideSecretsHelper(clonedData, true);
        auditRecord.actionParameters = hiddenData ? JSON.stringify(hiddenData) : 'null';
        // validate request...
        validateSchema(auditRecord, auditRecordSchema);
        // send to occm
        await gotInstance.post(OCCM_URL, { json: { auditRecord } });
        logger.info('**** sent audit record successfully **** auditRecord:', auditRecord);
    } catch (err) {
        logger.error('Failed to send audit record to audit service', err);
    }
}

module.exports = { sendAuditRecord };
