const {
    describeblobContainersSchema,
    createBlobContainerSchema,
    describeStorageAccountsSchema,
    describeAllStorageAccountsSchema,
    createStorageAccountSchema,
    updateStorageAccountTierLevelSchema,
    describeSubscriptionsSchema,
    createResourceGroupSchema,
    describeAllLocationsSchema,
    describeStorageAccountKeysSchema,
    describeResourceGroupsSchema
} = require('../validation/routes-schema-validation');
const {
    listBlobContainers, createBlobContainer
} = require('../lib/azure/blob-management');
const {
    listStorageAccounts,
    listStorageAccountsByResourceGroup,
    createStorageAccount,
    listStorageAccountKeys,
    updateStorageAccountTierLevel
} = require('../lib/azure/storage-management');
const { listSubscriptions, listLocations } = require('../lib/azure/subscription-management');
const { createResourceGroup, listResourceGroups } = require('../lib/azure/resource-management');

const API_PATH_AZURE = '/azure';

function azureRoutes(fastify) {
    fastify.get(`${API_PATH_AZURE}/storage-account-keys`, { schema: describeStorageAccountKeysSchema }, async request => {
        const { query: { resourceGroup, storageAccount } } = request;
        return listStorageAccountKeys(resourceGroup, storageAccount);
    });

    fastify.get(`${API_PATH_AZURE}/blob-containers`, { schema: describeblobContainersSchema }, async request => {
        const { query: { storageAccount, storageAccountKey } } = request;
        return listBlobContainers(storageAccount, storageAccountKey);
    });

    fastify.post(`${API_PATH_AZURE}/blob-containers`, { schema: createBlobContainerSchema }, async (request, reply) => {
        const {
            body: {
                storageAccount, containerName, storageAccountKey
            }
        } = request;
        await createBlobContainer(storageAccount, storageAccountKey, containerName);
        reply.code(200).send();
    });

    fastify.get(`${API_PATH_AZURE}/storage-accounts`, { schema: describeStorageAccountsSchema }, async request => {
        const { query: { resourceGroup } } = request;
        return listStorageAccountsByResourceGroup(resourceGroup);
    });

    fastify.get(`${API_PATH_AZURE}/all-storage-accounts`, { schema: describeAllStorageAccountsSchema }, async () => listStorageAccounts());

    fastify.post(`${API_PATH_AZURE}/storage-account`, { schema: createStorageAccountSchema }, async (request, reply) => {
        const {
            body: {
                resourceGroup, kind,
                skuName, location, storageAccount, accessTier
            }
        } = request;
        await createStorageAccount(resourceGroup, kind,
            skuName, location, storageAccount, accessTier);
        reply.code(200).send();
    });

    fastify.put(`${API_PATH_AZURE}/storage-account-tier-level`, { schema: updateStorageAccountTierLevelSchema }, async (request, reply) => {
        const {
            body: {
                resourceGroup, storageAccount, accessTier
            }
        } = request;
        await updateStorageAccountTierLevel(resourceGroup, storageAccount, accessTier);
        reply.code(200).send();
    });

    fastify.get(`${API_PATH_AZURE}/subscriptions`, { schema: describeSubscriptionsSchema }, async () => listSubscriptions());

    fastify.post(`${API_PATH_AZURE}/resource-group`, { schema: createResourceGroupSchema }, async (request, reply) => {
        const { body: { resourceGroup, location } } = request;
        await createResourceGroup(resourceGroup, location);
        reply.code(200).send();
    });

    fastify.get(`${API_PATH_AZURE}/resource-groups`, { schema: describeResourceGroupsSchema }, async () => listResourceGroups());

    fastify.get(`${API_PATH_AZURE}/locations`, { schema: describeAllLocationsSchema }, async () => listLocations());
}

module.exports = azureRoutes;
