const {
    createSgwsBucketSchema,
    getSgwsBucketsSchema, deleteSgwsObjectSchema, getSgwsObjectSchema, putSgwsObjectSchema
} = require('../validation/routes-schema-validation');
const {
    listSgwsBuckets, createSgwsBucket, deleteSgwsObject, getSgwsObject, putSgwsObject
} = require('../operations/aws-operations');

const API_PATH_AWS = '/sgws';

function sgwsRoutes(fastify) {
    fastify.get(`${API_PATH_AWS}/buckets`, { schema: getSgwsBucketsSchema }, async request => {
        const { headers: { secretkey, accesskey }, query: { host, port } } = request;
        return listSgwsBuckets({
            accessKeyId: accesskey, secretAccessKey: secretkey, host, port
        });
    });

    fastify.post(`${API_PATH_AWS}/bucket`, { schema: createSgwsBucketSchema }, async request => {
        const { headers: { secretkey, accesskey }, body: { name, host, port } } = request;
        await createSgwsBucket(name, {
            accessKeyId: accesskey, secretAccessKey: secretkey, host, port
        });
        return { name };
    });

    fastify.get(`${API_PATH_AWS}/:bucket/:key`, { schema: getSgwsObjectSchema }, async request => {
        const { params: { bucket, key }, headers: { secretkey: secretAccessKey, accesskey: accessKeyId }, query: { host, port } } = request;
        const keyBody = await getSgwsObject(bucket, key, {
            accessKeyId, secretAccessKey, host, port
        });
        return { keyBody };
    });

    fastify.put(`${API_PATH_AWS}/:bucket/:key`, { schema: putSgwsObjectSchema }, async (request, reply) => {
        const { params: { bucket, key }, headers: { secretkey: secretAccessKey, accesskey: accessKeyId }, body: { host, port, keyBody } } = request;
        await putSgwsObject(bucket, key, keyBody, {
            accessKeyId, secretAccessKey, host, port
        });
        reply.code(200).send();
    });

    fastify.delete(`${API_PATH_AWS}/:bucket/:key`, { schema: deleteSgwsObjectSchema }, async (request, reply) => {
        const { params: { bucket, key }, headers: { secretkey: secretAccessKey, accesskey: accessKeyId }, query: { host, port } } = request;
        await deleteSgwsObject(bucket, key, {
            accessKeyId, secretAccessKey, host, port
        });
        reply.code(200).send();
    });
}

module.exports = sgwsRoutes;
