const {
    modifyTieringFullnessThresholdSchema,
    describeVolumeMinimumCoolingDaysSchema,
    describeObjectStoresSchema, describeSvmLifsSchema, modifyVolumeSchema, describeNodesSystemImagesSchema,
    describeObjectStoreConfigsSchema, describeSystemInfoSchema, describeSvmsSchema, describeAggregatesSchema, describeClusterVolumesFootPrintSchema,
    describeDisksSchema, describeLicensesSchema, describeLicenseV2Schema, describeOntapUsersSchema, enableColdDataReportingSchema,
    describeSvmVolumesWithFilterSchema, modifyVolumeMinimumCoolingDaysSchema, applyLicenseV2Schema, describeClusterVolumesSchema, createObjectStoreConfigSchema, attachObjectStoreSchema,
    describeOntapVersionWithCredentialsSchema, describeOntapVersionWithPublicIdSchema, describeNodesWithCredentialsSchema, describeNodesWithPublicIdSchema,
    describeClusterInfoWithCredentialsSchema, describeClusterInfoWithPublicIdSchema
} = require('../validation/routes-schema-validation');
const {
    modifyTieringFullnessThreshold,
    describeOntapVersion, describeSvms, describeObjectStoreConfig, describeSystemInfo, describeObjectStores, describeUsers, describeAggregates, describeClusterInfo,
    describeClusterVolumesFootprint, describeDisks, describeLicenses, describeLicenseV2, describeSvmVolumesWithFilter, modifyColdDataReporting, describeNodes, describeNodeSystemImages,
    describeSvmLifs, attachObjectStore, createObjectStoreConfig, clusterVolumes, modifyVolume, applyLicenseV2, modifyVolumeMinimumCoolingDays, describeVolumesMinimumCoolingDays
} = require('../lib/zapi/zapi');

const getLogger = require('../utils/logger');

const logger = getLogger();

const API_PATH_ZAPI = '/zapi';

function zapiRoutes(fastify) {
    fastify.get(`${API_PATH_ZAPI}/:publicId/ontap-version`, { schema: describeOntapVersionWithPublicIdSchema }, async request => {
        const { params: { publicId } } = request;
        return describeOntapVersion(publicId);
    });

    fastify.get(`${API_PATH_ZAPI}/ontap-version`, { schema: describeOntapVersionWithCredentialsSchema }, async request => {
        const { headers: { clustermanagementip, username, password } } = request;
        return describeOntapVersion(undefined, clustermanagementip, username, password);
    });

    fastify.get(`${API_PATH_ZAPI}/:publicId/svms`, { schema: describeSvmsSchema }, async request => {
        const { params: { publicId }, query: { svmName } } = request;
        return describeSvms(publicId, svmName);
    });

    fastify.get(`${API_PATH_ZAPI}/:publicId/object-store-configs`, { schema: describeObjectStoreConfigsSchema }, async request => {
        const { params: { publicId } } = request;
        return describeObjectStoreConfig(publicId);
    });

    fastify.get(`${API_PATH_ZAPI}/:publicId/system-info`, { schema: describeSystemInfoSchema }, async request => {
        const { params: { publicId } } = request;
        return describeSystemInfo(publicId);
    });

    fastify.get(`${API_PATH_ZAPI}/:publicId/object-stores`, { schema: describeObjectStoresSchema }, async request => {
        const { params: { publicId } } = request;
        return describeObjectStores(publicId);
    });

    fastify.get(`${API_PATH_ZAPI}/users`, { schema: describeOntapUsersSchema }, async request => {
        const { headers: { clustermanagementip, username, password } } = request;
        return describeUsers(clustermanagementip, username, password);
    });

    fastify.get(`${API_PATH_ZAPI}/:publicId/aggregates`, { schema: describeAggregatesSchema }, async request => {
        const { params: { publicId } } = request;
        return describeAggregates(publicId);
    });

    fastify.get(`${API_PATH_ZAPI}/:publicId/cluster-info`, { schema: describeClusterInfoWithPublicIdSchema }, async request => {
        const { params: { publicId } } = request;
        return describeClusterInfo(publicId);
    });

    fastify.get(`${API_PATH_ZAPI}/cluster-info`, { schema: describeClusterInfoWithCredentialsSchema }, async request => {
        const { headers: { clustermanagementip, username, password } } = request;
        return describeClusterInfo(undefined, clustermanagementip, username, password);
    });

    fastify.get(`${API_PATH_ZAPI}/:publicId/cluster-volumes-foot-print`, { schema: describeClusterVolumesFootPrintSchema }, async request => {
        const { params: { publicId } } = request;
        return describeClusterVolumesFootprint(publicId);
    });

    fastify.get(`${API_PATH_ZAPI}/:publicId/cluster-volumes`, { schema: describeClusterVolumesSchema }, async request => {
        const { params: { publicId } } = request;
        return clusterVolumes(publicId);
    });

    fastify.get(`${API_PATH_ZAPI}/:publicId/disks`, { schema: describeDisksSchema }, async request => {
        const { params: { publicId } } = request;
        return describeDisks(publicId);
    });

    fastify.get(`${API_PATH_ZAPI}/:publicId/licenses`, { schema: describeLicensesSchema }, async request => {
        const { params: { publicId }, query: { svmName, volumeName } } = request;
        return describeLicenses(publicId, svmName, volumeName);
    });

    fastify.get(`${API_PATH_ZAPI}/:publicId/licenses-v2`, { schema: describeLicenseV2Schema }, async request => {
        const { params: { publicId } } = request;
        return describeLicenseV2(publicId);
    });

    fastify.get(`${API_PATH_ZAPI}/:publicId/:svmName/volumes`, { schema: describeSvmVolumesWithFilterSchema }, async request => {
        const { params: { publicId, svmName }, query: { volumeName } } = request;
        return describeSvmVolumesWithFilter(publicId, svmName, volumeName);
    });

    fastify.put(`${API_PATH_ZAPI}/:publicId/aggregates/:aggregateName/cold-data-reporting`, { schema: enableColdDataReportingSchema }, async (request, reply) => {
        const { params: { publicId, aggregateName }, body: { enable } } = request;
        await modifyColdDataReporting(publicId, aggregateName, enable);
        reply.code(200).send();
    });

    fastify.get(`${API_PATH_ZAPI}/:publicId/nodes`, { schema: describeNodesWithPublicIdSchema }, async request => {
        const { params: { publicId } } = request;
        return describeNodes(publicId);
    });

    fastify.get(`${API_PATH_ZAPI}/nodes`, { schema: describeNodesWithCredentialsSchema }, async request => {
        const { headers: { clustermanagementip, username, password } } = request;
        return describeNodes(undefined, clustermanagementip, username, password);
    });

    fastify.get(`${API_PATH_ZAPI}/:publicId/nodes-system-images`, { schema: describeNodesSystemImagesSchema }, async request => {
        const { params: { publicId }, query: { nodeName } } = request;
        return describeNodeSystemImages(publicId, nodeName);
    });

    fastify.get(`${API_PATH_ZAPI}/:publicId/svm-lifs`, { schema: describeSvmLifsSchema }, async request => {
        const { params: { publicId }, query: { svmName } } = request;
        return describeSvmLifs(publicId, svmName);
    });

    fastify.put(`${API_PATH_ZAPI}/:publicId/:svmName/volumes/:volumeName`, { schema: modifyVolumeSchema }, async (request, reply) => {
        const { params: { publicId, svmName, volumeName }, body: { tieringPolicy } } = request;
        // should we validate the ontap is on here?
        await modifyVolume(publicId, volumeName, svmName, tieringPolicy);
        reply.code(200).send();
    });

    fastify.get(`${API_PATH_ZAPI}/:publicId/volume-minimum-cooling-days`, { schema: describeVolumeMinimumCoolingDaysSchema }, async request => {
        const { params: { publicId } } = request;
        return describeVolumesMinimumCoolingDays(publicId);
    });

    fastify.put(`${API_PATH_ZAPI}/:publicId/volume-minimum-cooling-days`, { schema: modifyVolumeMinimumCoolingDaysSchema }, async (request, reply) => {
        const { params: { publicId }, body: { volumeName, days, svmName } } = request;
        const response = await modifyVolumeMinimumCoolingDays(publicId, volumeName, svmName, days);
        if (response.cliResultValue !== 1) {
            throw new Error(`modify-volume-minimum-cooling-days Failed: ${response.cliOutput}`);
        }
        reply.code(200).send();
    });

    fastify.put(`${API_PATH_ZAPI}/:publicId/tiering-fullness-threshold`, { schema: modifyTieringFullnessThresholdSchema }, async (request, reply) => {
        const { params: { publicId }, body: { aggregateName, objectStoreName, tieringFullnessThreshold } } = request;
        const response = await modifyTieringFullnessThreshold(publicId, aggregateName, objectStoreName, tieringFullnessThreshold);
        if (response.cliResultValue !== 1) {
            throw new Error(`modify-tiering-fullness-threshold Failed: ${response.cliOutput}`);
        }
        reply.code(200).send();
    });

    fastify.put(`${API_PATH_ZAPI}/:publicId/licenses-v2`, { schema: applyLicenseV2Schema }, async (request, reply) => {
        const { params: { publicId }, body: license } = request;
        logger.info(`About to apply license on cluster ${publicId}: ${license}`);
        await applyLicenseV2(publicId, license);
        reply.send();
    });

    fastify.post(`${API_PATH_ZAPI}/:publicId/object-store-configs`, { schema: createObjectStoreConfigSchema }, async request => {
        const {
            params: { publicId }, body: {
                objectStoreName, server, objectStoreProviderType, s3Name, azureAccount, azurePrivateKey, keys, ipSpace, checkOnly, port
            }
        } = request;
        return createObjectStoreConfig(publicId, objectStoreName, server, objectStoreProviderType, s3Name, azureAccount, azurePrivateKey, keys, ipSpace, port, checkOnly);
    });

    fastify.post(`${API_PATH_ZAPI}/:publicId/object-stores`, { schema: attachObjectStoreSchema }, async request => {
        const {
            params: { publicId }, body: {
                aggregateName, objectStoreName, checkOnly, allowFlexgroup
            }
        } = request;
        return attachObjectStore(publicId, aggregateName, objectStoreName, checkOnly, allowFlexgroup);
    });
}

module.exports = zapiRoutes;
