const convert = require('xml-js');
const createError = require('http-errors');
const ip = require('ip');
const { getConfigIdentity } = require('../lib/cloud-manager/config-operations');

async function getPublicIpAddress() {
    const { publicIp } = await getConfigIdentity();
    return publicIp || ip.address();
}

function parseXMLToJSON(data) {
    return convert.xml2js(data, {
        instructionHasAttributes: true, compact: true, ignoreComment: true, spaces: 4, nativeType: true
    });
}

function parseZapiXmlResponseToJSON(data) {
    const json = parseXMLToJSON(data);

    if (json.netapp.results._attributes.status === 'failed') {
        throw createError(403, json.netapp.results._attributes.reason);
    }

    return json.netapp.results;
}

function updateResponse(response) {
    return Array.isArray(response) ? response : [].concat(response);
}

module.exports = {
    parseZapiXmlResponseToJSON, parseXMLToJSON, updateResponse, getPublicIpAddress
};
