const {
    NONE, BACKUP, AUTO, ALL, SNAPSHOT_ONLY, STANDARD_AWS, MULTI_REGION, REGIONAL, OBJECT_STORE_CONFIG_TYPE, AWS, AZURE, GCP, SGWS,
    INTELLIGENT, ONE_ZONE_IA, STANDARD_IA, STANDARD, ARCHIVE, COLDLINE, NEARLINE
} = require('../utils/consts');

// AWS schemas:
const getAwsBucketsSchema = {
    tags: ['AWS'],
    description: 'List AWS buckets',
    response: {
        '200': {
            type: 'array',
            items: {
                type: 'object',
                properties: {
                    name: { type: 'string' },
                    region: { type: 'string' }
                }
            }
        }
    }
};

const createAwsBucketSchema = {
    tags: ['AWS'],
    description: 'Create AWS bucket',
    body: {
        type: 'object',
        properties: {
            name: { type: 'string' },
            region: { type: 'string' }
        }
    },
    response: {
        '200': {
            type: 'object',
            properties: {
                name: { type: 'string' },
                region: { type: 'string' }
            }
        }
    }
};

const getAwsRegionsSchema = {
    tags: ['AWS'],
    description: 'Get AWS regions',
    response: {
        '200': {
            type: 'array',
            items: {
                type: 'string'
            }
        }
    }
};

const describeAwsTierLevelSchema = {
    tags: ['AWS'],
    description: 'Get AWS bucket storage class',
    query: {
        type: 'object',
        properties: {
            bucket: { type: 'string' }
        }
    },
    response: {
        '200': {
            type: 'object',
            properties: {
                storageClass: { type: 'string', enum: [INTELLIGENT, ONE_ZONE_IA, STANDARD_IA, STANDARD_AWS] }
            }
        }
    }
};

const updateAwsTierLevelSchema = {
    tags: ['AWS'],
    description: 'Change AWS bucket storage class',
    body: {
        type: 'object',
        properties: {
            bucket: { type: 'string' },
            storageClass: { type: 'string', enum: [INTELLIGENT, ONE_ZONE_IA, STANDARD_IA] }
        }
    }
};

// GCP schemas:
const getGcpBucketsSchema = {
    tags: ['GCP'],
    description: 'list GCP buckets',
    response: {
        '200': {
            type: 'array',
            items: {
                type: 'object',
                properties: {
                    name: { type: 'string' },
                    region: { type: 'string' },
                    storageClass: { type: 'string', enum: [STANDARD, ARCHIVE, COLDLINE, NEARLINE] }
                }
            }
        }
    }
};

const createGcpBucketSchema = {
    tags: ['GCP'],
    description: 'create GCP bucket',
    body: {
        type: 'object',
        properties: {
            name: { type: 'string' },
            region: { type: 'string' }
        }
    },
    response: {
        '200': {
            type: 'object',
            properties: {
                name: { type: 'string' },
                region: { type: 'string' },
                storageClass: { type: 'string', enum: [REGIONAL, MULTI_REGION, STANDARD, ARCHIVE, COLDLINE, NEARLINE] }
            }
        }
    }
};

const updateGcpTierLevelSchema = {
    tags: ['GCP'],
    description: 'Change Gcp bucket storage class',
    body: {
        type: 'object',
        properties: {
            bucket: { type: 'string' },
            storageClass: { type: 'string', enum: [STANDARD, ARCHIVE, COLDLINE, NEARLINE] }
        }
    }
};

const getGcpRegionsSchema = {
    tags: ['GCP'],
    description: 'Get GCP regions',
    response: {
        '200': {
            type: 'array',
            items: {
                type: 'string'
            }
        }
    }
};

const getGcpProjectsSchema = {
    tags: ['GCP'],
    description: 'Get GCP Projects',
    response: {
        '200': {
            type: 'array',
            items: {
                type: 'object',
                properties: {
                    name: { type: 'string' },
                    projectId: { type: 'string' },
                    projectNumber: { type: 'string' },
                    lifecycleState: { type: 'string' },
                    createTime: { type: 'string' }
                }
            }
        }
    }
};

// ZAPI schemas:
const describeOntapVersionWithPublicIdSchema = {
    tags: ['Zapi'],
    description: 'Get ontap version',
    params: {
        publicId: {
            type: 'string'
        }
    },
    response: {
        '200': {
            type: 'object',
            properties: {
                generation: { type: 'string' },
                major: { type: 'string' },
                minor: { type: 'string' }
            }
        }
    }
};

const describeOntapVersionWithCredentialsSchema = {
    tags: ['Zapi'],
    description: 'Get ontap version',
    headers: {
        type: 'object',
        properties: {
            clustermanagementip: { type: 'string' },
            username: { type: 'string' },
            password: { type: 'string' }
        },
        required: ['clustermanagementip', 'username', 'password']
    },
    response: {
        '200': {
            type: 'object',
            properties: {
                generation: { type: 'string' },
                major: { type: 'string' },
                minor: { type: 'string' }
            }
        }
    }
};

const describeSvmsSchema = {
    tags: ['Zapi'],
    description: 'Get svms',
    params: {
        publicId: {
            type: 'string'
        }
    },
    query: {
        svmName: {
            type: 'string'
        }
    },
    response: {
        '200': {
            type: 'array',
            items: {
                type: 'object',
                properties: {
                    svmName: { type: 'string' },
                    svmType: { type: 'string' },
                    svmState: { type: 'string' },
                    svmSubType: { type: 'string' },
                    language: { type: 'string' },
                    allowedAggregates: { type: 'array', items: { type: 'string' } },
                    allowedProtocols: { type: 'array', items: { type: 'string' } }
                }
            }
        }
    }
};

const describeSvmVolumesWithFilterSchema = {
    tags: ['Zapi'],
    description: 'Get svm volumes',
    params: {
        publicId: {
            type: 'string'
        },
        svmName: {
            type: 'string'
        }
    },
    response: {
        '200': {
            type: 'array',
            items: {
                type: 'object',
                properties: {
                    name: { type: 'string' },
                    svmName: { type: 'string' },
                    uuid: { type: 'string' },
                    usedSize: { type: 'number' },
                    sizeTotal: { type: 'number' },
                    state: { type: 'string' },
                    isVserverRoot: { type: 'boolean' },
                    aggregateName: { type: 'string' },
                    volumeType: { type: 'string' },
                    creationTime: { type: 'string' },
                    tieringPolicy: { type: 'string' },
                    tierInactiveUserData: { type: 'number' },
                    tierInactiveUserDataPercent: { type: 'number' },
                    physicalUsed: { type: 'number' },
                    flexgroupMSid: { type: 'string' },
                    flexgroupConstituentIndex: { type: 'string' },
                    snapshotsUsedSize: { type: 'number' }
                },
                additionalProperties: true
            }
        }
    }
};

const describeClusterVolumesSchema = {
    tags: ['Zapi'],
    description: 'Get cluster volumes',
    params: {
        publicId: {
            type: 'string'
        }
    },
    response: {
        '200': {
            type: 'array',
            items: {
                type: 'object',
                properties: {
                    volumeCompAggrAttributes: {
                        type: 'object',
                        properties: {
                            tieringPolicy: { type: 'string' }
                        }
                    },
                    volumeIdAttributes: {
                        type: 'object',
                        properties: {
                            containingAggregateName: { type: 'string' },
                            creationTime: { type: 'number' },
                            instanceUUID: { type: 'string' },
                            name: { type: 'string' },
                            owningVserverName: { type: 'string' },
                            type: { type: 'string' }
                        }
                    },
                    volumeSpaceAttributes: {
                        type: 'object',
                        properties: {
                            performanceTierInactiveUserData: { type: 'number' },
                            performanceTierInactiveUserDataPercent: { type: 'number' },
                            physicalUsed: { type: 'number' },
                            size: { type: 'number' },
                            sizeUsed: { type: 'number' },
                            spaceGuarantee: { type: 'string' }
                        }
                    },
                    volumeStateAttributes: {
                        type: 'object',
                        properties: {
                            state: { type: 'string' },
                            isVserverRoot: { type: 'boolean' }
                        }
                    }
                }
            }
        }
    }
};

const describeAggregatesSchema = {
    tags: ['Zapi'],
    description: 'Get aggregates',
    params: {
        publicId: {
            type: 'string'
        }
    },
    response: {
        '200': {
            type: 'array',
            items: {
                type: 'object',
                properties: {
                    name: { type: 'string' },
                    state: { type: 'string' },
                    isRoot: { type: 'boolean' },
                    isComposite: { type: 'boolean' },
                    isInactiveDataReportingEnabled: { type: 'boolean' },
                    isObjectStoreAttachEligible: { type: 'boolean' },
                    homeName: { type: 'string' },
                    ownerName: { type: 'string' },
                    isSidl: { type: 'boolean' },
                    availableCapacity: { type: 'number' },
                    totalCapacity: { type: 'number' },
                    usedCapacity: { type: 'number' },
                    tierInactiveUserData: { type: 'number' },
                    tierInactiveUserDataPercent: { type: 'number' },
                    plexName: { type: 'string' },
                    raidGroupName: { type: 'string' }
                }
            }
        }
    }
};

const describeOntapUsersSchema = {
    tags: ['Zapi'],
    description: 'Get ontap users',
    headers: {
        type: 'object',
        properties: {
            clustermanagementip: { type: 'string' },
            username: { type: 'string' },
            password: { type: 'string' }
        },
        required: ['clustermanagementip', 'username', 'password']
    },
    response: {
        '200': {
            type: 'array',
            items: {
                type: 'object',
                properties: {
                    userName: { type: 'string' },
                    application: { type: 'string' },
                    authMethod: { type: 'string' },
                    role: { type: 'string' }
                }
            }
        }
    }
};

const enableColdDataReportingSchema = {
    tags: ['Zapi'],
    description: 'Enable cold data reporting',
    params: {
        publicId: {
            type: 'string'
        },
        aggregateName: {
            type: 'string'
        }
    },
    body: {
        enable: {
            type: 'boolean'
        }
    },
    response: {
        '200': {
            type: 'null'
        }
    }
};

const modifyVolumeSchema = {
    tags: ['Zapi'],
    description: 'Modify volume',
    params: {
        publicId: {
            type: 'string'
        },
        volumeName: {
            type: 'string'
        },
        svmName: {
            type: 'string'
        }
    },
    body: {
        tieringPolicy:
            {
                type: 'string',
                enum: [NONE, BACKUP, AUTO, ALL, SNAPSHOT_ONLY]
            }
    },
    response: {
        '200': {
            type: 'null'
        }
    }
};

const modifyVolumeMinimumCoolingDaysSchema = {
    tags: ['Zapi'],
    description: 'Modify volume minimum cooling days',
    params: {
        publicId: {
            type: 'string'
        }
    },
    body: {
        volumeName: {
            type: 'string'
        },
        svmName: {
            type: 'string'
        },
        days: {
            type: 'number'
        }
    },
    response: {
        '200': {
            type: 'string'
        }
    }
};

const modifyTieringFullnessThresholdSchema = {
    tags: ['Zapi'],
    description: 'Modify tiering fullness threshold',
    params: {
        publicId: {
            type: 'string'
        }
    },
    body: {
        aggregateName: {
            type: 'string'
        },
        objectStoreName: {
            type: 'string'
        },
        tieringFullnessThreshold: {
            type: 'number'
        }
    },
    response: {
        '200': {
            type: 'string'
        }
    }
};

const applyLicenseV2Schema = {
    tags: ['Zapi'],
    description: 'Apply license',
    params: {
        publicId: {
            type: 'string'
        }
    },
    body: {
        type: 'object',
        properties: {
            statusResp: {
                type: 'object',
                properties: {
                    serialNumber: { type: 'string' },
                    version: { type: 'string' },
                    product: { type: 'string' },
                    licenses: {
                        type: 'object',
                        propeties: {
                            capacity: { type: 'number' },
                            type: { type: 'string' },
                            package: { type: 'string' }
                        }
                    }
                }
            },
            trackingId: { type: 'string' },
            Signature: { type: 'string' }
        }
    },
    response: {
        '200': {
            type: 'string'
        }
    }
};

const attachObjectStoreSchema = {
    tags: ['Zapi'],
    description: 'Attach object store',
    params: {
        publicId: {
            type: 'string'
        }
    },
    body: {
        type: 'object',
        required: ['aggregateName', 'objectStoreName'],
        properties: {
            aggregateName: {
                type: 'string'
            },
            objectStoreName: {
                type: 'string'
            },
            checkOnly: {
                type: 'boolean'
            },
            allowFlexgroup: {
                type: 'boolean'
            }
        }
    },
    response: {
        '200': {
            type: 'object',
            properties: {
                isAggregateRestricted: { type: 'boolean' },
                reason: { type: 'string' }
            }
        }
    }
};

const describeClusterAddressSchema = {
    tags: ['Zapi'],
    description: 'Get cluster address',
    params: {
        publicId: {
            type: 'string'
        }
    },
    response: {
        '200': {
            type: 'string'
        }
    }
};

const createObjectStoreConfigSchema = {
    tags: ['Zapi'],
    description: 'Create object store config',
    params: {
        publicId: {
            type: 'string'
        }
    },
    body: {
        type: 'object',
        required: ['objectStoreName', 'server', 'objectStoreProviderType', 'ipSpace', 'checkOnly'],
        properties: {
            objectStoreName: {
                type: 'string'
            },
            server: {
                type: 'string'
            },
            objectStoreProviderType: {
                type: 'string',
                enum: [OBJECT_STORE_CONFIG_TYPE[AWS], OBJECT_STORE_CONFIG_TYPE[AZURE], OBJECT_STORE_CONFIG_TYPE[GCP], OBJECT_STORE_CONFIG_TYPE[SGWS]]
            },
            azureAccount: {
                type: 'string'
            },
            azurePrivateKey: {
                type: 'string'
            },
            ipSpace: {
                type: 'string'
            },
            checkOnly: {
                type: 'boolean'
            },
            keys: {
                type: 'object',
                properties: {
                    accessKey: { type: 'string' },
                    secretKey: { type: 'string' }
                }
            }
        }
    },
    response: {
        '200': {
            type: 'null'
        }
    }
};

const describeSystemInfoSchema = {
    tags: ['Zapi'],
    description: 'Get system info',
    params: {
        publicId: {
            type: 'string'
        }
    },
    response: {
        '200': {
            type: 'array',
            items: {
                type: 'object',
                properties: {
                    systemId: { type: 'string' },
                    systemVersion: { type: 'string' },
                    serialNumber: { type: 'string' },
                    nodeName: { type: 'string' }
                }
            }
        }
    }
};

const describeClusterInfoWithPublicIdSchema = {
    tags: ['Zapi'],
    description: 'Get cluster info',
    params: {
        publicId: {
            type: 'string'
        }
    },
    response: {
        '200': {
            type: 'object',
            properties: {
                clusterUuid: { type: 'string' },
                clusterName: { type: 'string' },
                serialNumber: { type: 'string' }
            }
        }
    }
};

const describeClusterInfoWithCredentialsSchema = {
    tags: ['Zapi'],
    description: 'Get cluster info',
    headers: {
        type: 'object',
        properties: {
            clustermanagementip: { type: 'string' },
            username: { type: 'string' },
            password: { type: 'string' }
        },
        required: ['clustermanagementip', 'username', 'password']
    },
    response: {
        '200': {
            type: 'object',
            properties: {
                clusterUuid: { type: 'string' },
                clusterName: { type: 'string' },
                serialNumber: { type: 'string' }
            }
        }
    }
};

const describeClusterVolumesFootPrintSchema = {
    tags: ['Zapi'],
    description: 'Get cluster volumes footprint',
    params: {
        publicId: {
            type: 'string'
        }
    },
    response: {
        '200': {
            type: 'array',
            items: {
                type: 'object',
                properties: {
                    name: { type: 'string' },
                    svmName: { type: 'string' },
                    performanceTierFootprint: { type: 'number' },
                    capacityTierFootprint: { type: 'number' }
                }
            }
        }
    }
};

const describeDisksSchema = {
    tags: ['Zapi'],
    description: 'Get disks',
    params: {
        publicId: {
            type: 'string'
        }
    },
    response: {
        '200': {
            type: 'array',
            items: {
                type: 'object',
                properties: {
                    diskName: { type: 'string' },
                    diskRaidInfoPosition: { type: 'string' },
                    diskOwnershipInfoOwnerNodeName: { type: 'string' },
                    diskRaidInfoDiskAggregateInfoAggregateName: { type: 'string' },
                    diskRaidInfoContainerType: { type: 'string' },
                    diskRaidInfoDiskOutageInfoReason: { type: 'string' },
                    diskPathsDiskPathInfo: {
                        type: 'array',
                        items: {
                            type: 'object',
                            properties: {
                                vmdiskHypervisorFileName: { type: 'string' },
                                initiatorPort: { type: 'string' },
                                node: { type: 'string' }
                            }
                        }
                    },
                    diskInventoryInfoVirtualMachineDiskInfo: {
                        type: 'array',
                        items: {
                            type: 'object',
                            properties: {
                                vmdiskObjectName: { type: 'string' },
                                vmdiskStorageAccount: { type: 'string' },
                                vmdiskContainerName: { type: 'string' }
                            }
                        }
                    },
                    diskRaidInfoPhysicalBlocks: { type: 'string' }
                }
            }
        }
    }
};

const describeLicensesSchema = {
    tags: ['Zapi'],
    description: 'Get licenses',
    params: {
        publicId: {
            type: 'string'
        }
    },
    query: {
        svmName: {
            type: 'string'
        },
        volumeName: {
            type: 'string'
        }
    },
    response: {
        '200': {
            type: 'array',
            items: {
                type: 'object',
                properties: {
                    package: { type: 'string' },
                    description: { type: 'string' },
                    expirationTime: { type: 'string' }
                }
            }
        }
    }
};

const describeLicenseV2Schema = {
    tags: ['Zapi'],
    description: 'Get license',
    params: {
        publicId: {
            type: 'string'
        }
    },
    response: {
        '200': {
            type: 'array',
            items: {
                type: 'object',
                properties: {
                    package: { type: 'string' },
                    currentCapacity: { type: 'number' },
                    maxCapacity: { type: 'number' },
                    serialNumber: { type: 'string' }
                }
            }
        }
    }
};

const describeSvmLifsSchema = {
    tags: ['Zapi'],
    description: 'Get svm lifs',
    params: {
        publicId: {
            type: 'string'
        }
    },
    query: {
        svmName: {
            type: 'string'
        }
    },
    response: {
        '200': {
            type: 'array',
            items: {
                type: 'object',
                properties: {
                    firewallPolicy: { type: 'string' },
                    failoverPolicy: { type: 'string' },
                    interfaceName: { type: 'string' },
                    address: { type: 'string' },
                    netmask: { type: 'string' },
                    netmaskLength: { type: 'string' },
                    port: { type: 'string' },
                    node: { type: 'string' },
                    status: { type: 'string' },
                    svmName: { type: 'string' },
                    homeNode: { type: 'string' },
                    ipSpace: { type: 'string' },
                    role: {
                        type: 'string',
                        enum: ['undef', 'cluster_mgmt', 'intercluster', 'node_mgmt', 'data', 'cluster']
                    }
                }
            }
        }
    }
};

const describeObjectStoresSchema = {
    tags: ['Zapi'],
    description: 'Get object stores',
    params: {
        publicId: {
            type: 'string'
        }
    },
    response: {
        '200': {
            type: 'array',
            items: {
                type: 'object',
                properties: {
                    aggregateName: { type: 'string' },
                    availabilityState: { type: 'string', enum: ['available', 'unavailable'] },
                    name: { type: 'string' },
                    usedSpace: { type: 'number' },
                    tieringFullnessThreshold: { type: 'number' }
                }
            }
        }
    }
};

const describeObjectStoreConfigsSchema = {
    tags: ['Zapi'],
    description: 'Get object store configs',
    params: {
        publicId: {
            type: 'string'
        }
    },
    response: {
        '200': {
            type: 'array',
            items: {
                type: 'object',
                properties: {
                    objectStoreName: { type: 'string' },
                    s3Name: { type: 'string' },
                    usedSpace: { type: 'number' },
                    server: { type: 'string' },
                    providerType: { type: 'string' }
                }
            }
        }
    }
};

const describeNodesWithPublicIdSchema = {
    tags: ['Zapi'],
    description: 'Get nodes',
    params: {
        publicId: {
            type: 'string'
        }
    },
    response: {
        '200': {
            type: 'array',
            items: {
                type: 'object',
                properties: {
                    nodeName: { type: 'string' },
                    model: { type: 'string' },
                    isNodeHealthy: { type: 'boolean' },
                    isClusterEligible: { type: 'boolean' }
                }
            }
        }
    }
};

const describeNodesWithCredentialsSchema = {
    tags: ['Zapi'],
    description: 'Get nodes',
    headers: {
        type: 'object',
        properties: {
            clustermanagementip: { type: 'string' },
            username: { type: 'string' },
            password: { type: 'string' }
        },
        required: ['clustermanagementip', 'username', 'password']
    },
    response: {
        '200': {
            type: 'array',
            items: {
                type: 'object',
                properties: {
                    nodeName: { type: 'string' },
                    model: { type: 'string' },
                    isNodeHealthy: { type: 'boolean' },
                    isClusterEligible: { type: 'boolean' }
                }
            }
        }
    }
};

const describeVolumeMinimumCoolingDaysSchema = {
    tags: ['Zapi'],
    description: 'Get volume minimum cooling days',
    params: {
        publicId: {
            type: 'string'
        }
    },
    response: {
        '200': {
            type: 'object',
            properties: {
                cliResultValue: { type: 'object', properties: { status: { type: 'string' } } },
                cliOutput: { type: 'string' },
                attributes: { type: 'string' }
            }
        }
    }
};

const describeNodesSystemImagesSchema = {
    tags: ['Zapi'],
    description: 'Get nodes system images',
    params: {
        publicId: {
            type: 'string'
        }
    },
    query: {
        nodeName: {
            type: 'string'
        }
    },
    response: {
        '200': {
            type: 'array',
            items: {
                type: 'object',
                properties: {
                    image: { type: 'string' },
                    isCurrent: { type: 'boolean' },
                    isDefault: { type: 'boolean' },
                    version: { type: 'string' }
                }
            }
        }
    }
};

// AZURE schemas:

const describeblobContainersSchema = {
    tags: ['AZURE'],
    description: 'Get Azure storage account containers',
    querystring: {
        type: 'object',
        required: ['storageAccount', 'storageAccountKey'],
        properties: {
            storageAccount: { type: 'string' },
            storageAccountKey: { type: 'string' }
        }
    },
    response: {
        '200': {
            type: 'array',
            items: {
                type: 'string'
            }
        }
    }
};

const describeStorageAccountKeysSchema = {
    tags: ['AZURE'],
    description: 'Get Azure storage account keys',
    querystring: {
        type: 'object',
        required: ['resourceGroup', 'storageAccount'],
        properties: {
            storageAccount: { type: 'string' },
            resourceGroup: { type: 'string' }
        }
    },
    response: {
        '200': {
            type: 'object',
            properties: {
                keys: {
                    type: 'array',
                    items: {
                        type: 'object',
                        properties: {
                            keyName: { type: 'string' },
                            value: { type: 'string' },
                            permissions: { type: 'string' }
                        }
                    }
                }
            }
        }
    }
};

const createBlobContainerSchema = {
    tags: ['AZURE'],
    description: 'Create Azure blob containers',
    body: {
        type: 'object',
        required: ['storageAccount', 'storageAccountKey', 'containerName'],
        properties: {
            storageAccount: { type: 'string' },
            storageAccountKey: { type: 'string' },
            containerName: { type: 'string' }
        }
    },
    response: {
        '200': {
            type: 'string'
        }
    }
};

const describeStorageAccountsSchema = {
    tags: ['AZURE'],
    description: 'Get Azure storage accounts by resource group',
    querystring: {
        type: 'object',
        required: ['resourceGroup'],
        properties: {
            resourceGroup: { type: 'string' }
        }
    },
    '200': {
        type: 'array',
        items: {
            type: 'object',
            additionalProperties: true,
            properties: {
                id: { type: 'string' },
                name: { type: 'string' },
                location: { type: 'string' },
                accessTier: { type: 'string' },
                kind: { type: 'string' }
            }
        }
    }
};

const describeAllStorageAccountsSchema = {
    tags: ['AZURE'],
    description: 'Get Azure storage accounts',
    response: {
        '200': {
            type: 'array',
            items: {
                type: 'object',
                additionalProperties: true,
                properties: {
                    id: { type: 'string' },
                    name: { type: 'string' },
                    location: { type: 'string' },
                    accessTier: { type: 'string' },
                    kind: { type: 'string' }
                }
            }
        }
    }
};

const createStorageAccountSchema = {
    tags: ['AZURE'],
    description: 'Create Azure storage account',
    body: {
        type: 'object',
        required: ['resourceGroup', 'kind', 'skuName', 'location', 'storageAccount', 'accessTier'],
        properties: {
            resourceGroup: { type: 'string' },
            kind: { type: 'string' },
            skuName: { type: 'string' },
            location: { type: 'string' },
            storageAccount: { type: 'string' },
            accessTier: { type: 'string' }
        }
    },
    response: {
        '200': {
            type: 'string'
        }
    }
};

const updateStorageAccountTierLevelSchema = {
    tags: ['AZURE'],
    description: 'Update Azure storage account tier level',
    body: {
        type: 'object',
        required: ['resourceGroup', 'storageAccount', 'accessTier'],
        properties: {
            resourceGroup: { type: 'string' },
            storageAccount: { type: 'string' },
            accessTier: { type: 'string', enum: ['Cool', 'Hot'] }
        }
    },
    response: {
        '200': {
            type: 'null'
        }
    }
};

const describeSubscriptionsSchema = {
    tags: ['AZURE'],
    description: 'Get Azure subscriptions',
    response: {
        '200': {
            type: 'array',
            items: {
                type: 'object',
                properties: {
                    subscriptionId: {
                        type: 'string'
                    },
                    state: { type: 'string' },
                    displayName: { type: 'string' }
                },
                additionalProperties: true
            }
        }
    }
};

const createResourceGroupSchema = {
    tags: ['AZURE'],
    description: 'Create Azure resource group',
    body: {
        type: 'object',
        required: ['resourceGroup', 'location'],
        properties: {
            resourceGroup: { type: 'string' },
            location: { type: 'string' }
        }
    },
    response: {
        '200': {
            type: 'string'
        }
    }
};

const describeResourceGroupsSchema = {
    tags: ['AZURE'],
    description: 'Get Azure storage accounts',
    response: {
        '200': {
            type: 'array',
            items: {
                type: 'object',
                properties: {
                    name: { type: 'string' },
                    location: { type: 'string' }
                }
            }
        }
    }
};

const describeAllLocationsSchema = {
    tags: ['AZURE'],
    description: 'Get Azure locations',
    response: {
        '200': {
            type: 'array',
            items: {
                type: 'object',
                properties: {
                    name: { type: 'string' },
                    displayName: { type: 'string' }
                },
                additionalProperties: true
            }
        }
    }
};

// Health schemas:
const getHealthinessSchema = {
    tags: ['Health'],
    description: 'Get server healthiness',
    response: {
        '200': {
            type: 'object',
            properties: {
                passed: { type: 'string' },
                reason: { type: 'string' }
            }
        }
    }
};

// System schemas:
const aboutSchema = {
    tags: ['System'],
    description: 'Get system version',
    response: {
        '200': {
            type: 'object',
            properties: {
                version: { type: 'string' },
                'node-version': { type: 'string' },
                mode: { type: 'string' },
                build: { type: 'string' },
                git: { type: 'string' }
            }
        }
    }
};

const canUpgradeSchema = {
    tags: ['System'],
    description: 'Whether system can upgrade',
    response: {
        '200': {
            type: 'object',
            properties: {
                passed: { type: 'string' },
                reason: { type: 'string' }
            }
        }
    }
};

// SGWS schemas
const getSgwsBucketsSchema = {
    tags: ['SGWS'],
    description: 'List SGWS buckets',
    query: {
        host: { type: 'string' },
        port: { type: 'string' }
    },
    headers: {
        accessKey: { type: 'string' },
        secretKey: { type: 'string' }
    },
    response: {
        '200': {
            type: 'array',
            items: {
                type: 'object',
                properties: {
                    name: { type: 'string' }
                }
            }
        }
    }
};
const createSgwsBucketSchema = {
    tags: ['SGWS'],
    description: 'Create SGWS bucket',
    query: {
        host: { type: 'string' },
        port: { type: 'string' }
    },
    headers: {
        accessKey: { type: 'string' },
        secretKey: { type: 'string' }
    },
    body: {
        type: 'object',
        properties: {
            name: { type: 'string' }
        }
    },
    response: {
        '200': {
            type: 'object',
            properties: {
                name: { type: 'string' }
            }
        }
    }
};

const deleteSgwsObjectSchema = {
    tags: ['SGWS'],
    description: 'Delete object from SGWS bucket',
    params: {
        bucket: {
            type: 'string'
        },
        key: {
            type: 'string'
        }
    },
    query: {
        host: { type: 'string' },
        port: { type: 'string' }
    },
    headers: {
        accessKey: { type: 'string' },
        secretKey: { type: 'string' }
    },
    response: {
        '200': {
            type: 'null'
        }
    }
};

const getSgwsObjectSchema = {
    tags: ['SGWS'],
    description: 'Get object from SGWS bucket',
    params: {
        bucket: {
            type: 'string'
        },
        key: {
            type: 'string'
        }
    },
    query: {
        host: { type: 'string' },
        port: { type: 'string' }
    },
    headers: {
        accessKey: { type: 'string' },
        secretKey: { type: 'string' }
    },
    response: {
        '200': {
            type: 'object',
            properties: {
                keyBody: { type: 'string' }
            }
        }
    }
};
const putSgwsObjectSchema = {
    tags: ['SGWS'],
    description: 'Get object from SGWS bucket',
    params: {
        bucket: {
            type: 'string'
        },
        key: {
            type: 'string'
        }
    },
    body: {
        type: 'object',
        properties: {
            host: { type: 'string' },
            port: { type: 'string' },
            keyBody: { type: 'string' }
        }
    },
    headers: {
        accessKey: { type: 'string' },
        secretKey: { type: 'string' }
    },
    response: {
        '200': {
            type: 'null'
        }
    }
};

module.exports = {
    getAwsBucketsSchema,
    createAwsBucketSchema,
    updateAwsTierLevelSchema,
    getAwsRegionsSchema,
    describeAwsTierLevelSchema,
    getGcpBucketsSchema,
    createGcpBucketSchema,
    getGcpRegionsSchema,
    updateGcpTierLevelSchema,
    getGcpProjectsSchema,
    describeAggregatesSchema,
    describeClusterVolumesSchema,
    describeOntapUsersSchema,
    describeblobContainersSchema,
    createBlobContainerSchema,
    describeStorageAccountsSchema,
    describeAllStorageAccountsSchema,
    describeStorageAccountKeysSchema,
    createStorageAccountSchema,
    updateStorageAccountTierLevelSchema,
    describeSubscriptionsSchema,
    createResourceGroupSchema,
    describeObjectStoreConfigsSchema,
    describeAllLocationsSchema,
    enableColdDataReportingSchema,
    describeSystemInfoSchema,
    describeNodesSystemImagesSchema,
    modifyVolumeSchema,
    describeClusterVolumesFootPrintSchema,
    describeDisksSchema,
    describeLicensesSchema,
    describeLicenseV2Schema,
    describeSvmsSchema,
    describeSvmVolumesWithFilterSchema,
    describeSvmLifsSchema,
    describeObjectStoresSchema,
    modifyVolumeMinimumCoolingDaysSchema,
    applyLicenseV2Schema,
    getHealthinessSchema,
    aboutSchema,
    canUpgradeSchema,
    createObjectStoreConfigSchema,
    attachObjectStoreSchema,
    describeVolumeMinimumCoolingDaysSchema,
    describeClusterAddressSchema,
    describeOntapVersionWithPublicIdSchema,
    describeOntapVersionWithCredentialsSchema,
    describeNodesWithCredentialsSchema,
    describeNodesWithPublicIdSchema,
    describeClusterInfoWithPublicIdSchema,
    describeClusterInfoWithCredentialsSchema,
    getSgwsBucketsSchema,
    createSgwsBucketSchema,
    deleteSgwsObjectSchema,
    getSgwsObjectSchema,
    putSgwsObjectSchema,
    modifyTieringFullnessThresholdSchema,
    describeResourceGroupsSchema
};
