const Joi = require('@hapi/joi');
const { ON_STATUS, FAILED_STATUS } = require('../utils/consts');

/** *******************************************
 *          Response validations             *
 ******************************************** */

const capacitySchema = Joi.object().keys({
    size: Joi.number().required(),
    unit: Joi.string().required()
});

const objectStoreConfigSchema = Joi.object().keys({
    objectStoreName: Joi.string().required(),
    s3Name: Joi.string().required(),
    usedSpace: capacitySchema.required(),
    providerType: Joi.string().required(),
    server: Joi.string().required()
});

const capacityFeaturesSchema = Joi.object().keys({
    objectStoreConfigExtended: Joi.object().keys({
        objectStoreConfig: objectStoreConfigSchema.allow(null),
        tierLevel: Joi.string().valid('normal', 'coldline', 'nearline', 'ia', 'hot', 'cool', 'STANDARD', 'ia-single', 'intelligent').allow(null)
    }).allow(null)
});

const lifSchema = Joi.object().keys({
    name: Joi.string(),
    role: Joi.string().valid('undef', 'data', 'node_mgmt', 'cluster_mgmt', 'cluster', 'intercluster'),
    status: Joi.string().valid('up', 'down', 'undefined'),
    ipSpace: Joi.string().allow('')
});

const clusterResponseSchema = Joi.object().keys({
    name: Joi.string().required(),
    publicId: Joi.string().required(),
    ontapClusterProperties: Joi.object().keys({
        clusterUuid: Joi.string().required(),
        ontapVersion: Joi.string().required().allow(''),
        clusterAddress: Joi.string().required(),
        lifs: Joi.array().items(lifSchema),
        nodeModels: Joi.array().items(Joi.string())
    }).allow(null),
    capacityFeatures: capacityFeaturesSchema.allow(null),
    status: Joi.object().keys({
        status: Joi.string().required().valid(ON_STATUS, FAILED_STATUS),
        message: Joi.string().allow('', null),
        failureCauses: Joi.object().keys({
            invalidOntapCredentials: Joi.boolean()
        }).allow(null),
        extendedFailureReason: Joi.string().allow(null)
    }).allow(null)
});

module.exports = {
    clusterResponseSchema
};
