const {
    AGENT_LIST_GCP_REGIONS, AGENT_LIST_GCP_BUCKETS,
    AGENT_SET_GCP_STORAGE_CLASS
} = require('../../utils/consts');
const { validateResponse, validateRequest } = require('../../utils/schema-validation');
const {
    setGcpStorageClassRequestSchema, createBucketRequestSchema, regionsResponse, gcpBucketsResponse, gcpBucket
} = require('../../joi-schemas/agent-schemas');
const getLogger = require('../../utils/logger/logger');
const { gotInstanceForAgent } = require('../../utils/got-utils');
const { createAgentPath, createHeadersForAgent } = require('../../utils/utils');

const logger = getLogger();

async function getGcpRegions(agentId) {
    logger.info('Getting GCP regions for agent id:', agentId);
    const data = await gotInstanceForAgent.get(createAgentPath(AGENT_LIST_GCP_REGIONS), createHeadersForAgent(agentId));
    validateResponse(data, regionsResponse);
    return data;
}

async function getGcpBuckets(agentId) {
    logger.info('Getting GCP buckets for agent id:', agentId);
    const data = await gotInstanceForAgent.get(createAgentPath(AGENT_LIST_GCP_BUCKETS), createHeadersForAgent(agentId));
    validateResponse(data, gcpBucketsResponse);
    return data;
}

async function createGcpBucket(agentId, name, region) {
    logger.debug('Creating GCP bucket:', {
        agentId, name, region
    });
    const requestData = { name, region };
    validateRequest(requestData, createBucketRequestSchema);
    const data = await gotInstanceForAgent.post(createAgentPath(AGENT_LIST_GCP_BUCKETS), { json: requestData, ...createHeadersForAgent(agentId) });
    validateResponse(data, gcpBucket);

    return data;
}

async function setGcpStorageClass(agentId, bucket, storageClass) {
    logger.debug('Setting GCP storage class:', {
        agentId, bucket, storageClass
    });
    const requestData = { bucket, storageClass };
    validateRequest(requestData, setGcpStorageClassRequestSchema);
    await gotInstanceForAgent.put(createAgentPath(AGENT_SET_GCP_STORAGE_CLASS), { json: requestData, ...createHeadersForAgent(agentId) });
}

module.exports = {
    getGcpRegions, getGcpBuckets, createGcpBucket, setGcpStorageClass
};
