const config = require('config');
const { SUBSCRIPTION_BASE_URL } = require('../utils/consts');
const { getServiceToken } = require('./auth0');
const { listSubscriptionByServiceNameResponse, listSubscriptionResponse } = require('../joi-schemas/subscription-schemas');
const { gotInstanceForOuterServices } = require('../utils/got-utils');
const { validateResponse } = require('../utils/schema-validation');
const { getUserToken } = require('../utils/async-local-storage');

async function listSubscriptionsOfAccount(accountId) {
    const headers = (process.env.IS_SIMULATOR) ? {
        headers: {
            authorization: getServiceToken(),
            'X-User-Token': getUserToken()
        }
    } : { headers: { authorization: getServiceToken() } };
    const data = await gotInstanceForOuterServices.get(`${SUBSCRIPTION_BASE_URL}/${accountId}`, headers);
    // data is [{subscriptionId, cloudProvider, name, status, serviceName}]
    validateResponse(data, listSubscriptionResponse);
    return data;
}

async function listSubscriptionsForService(serviceName, continuationToken) {
    const contToken = continuationToken ? `&continuationToken=${continuationToken}` : '';
    const url = `${SUBSCRIPTION_BASE_URL}/by-service-name?serviceName=${serviceName}&v2=true&pageLimit=${config.get('charging.list-subscription-page-limit')}${contToken}`;
    const data = await gotInstanceForOuterServices.get(url, {
        headers: {
            authorization: getServiceToken()
        }
    });
    validateResponse(data, listSubscriptionByServiceNameResponse);
    return data;
}

module.exports = { listSubscriptionsOfAccount, listSubscriptionsForService };
