const authenticate = require('../operations/authentication-operations');
const getLogger = require('../utils/logger/logger');

const logger = getLogger();

async function authenticationMiddleware(req, res, next) {
    // if in order to support playground - and do express authentication only on rest API. for graphql the authentication will be in a different place
    if (!((req.path === '/graphql') || (req.body && req.body.operationName === 'IntrospectionQuery'))) {
        const authorization = req.get('Authorization') || req.get('authorization');

        logger.debug('Authorization header:', authorization);
        try {
            await authenticate(authorization, req);
            next();
        } catch (err) {
            logger.debug(`Failed authenticating user with JWT token - authorization ${authorization}:`, err);
            res.status(401).send({ message: 'UNAUTHORIZED', status: 401 });
        }
    } else {
        next();
    }
}

module.exports = authenticationMiddleware;
