const mongoose = require('mongoose');
const { SUBSCRIBED } = require('../utils/consts');
const getLogger = require('../utils/logger/logger');

const logger = getLogger();

const mpSubscriptionSchema = new mongoose.Schema({
    accountId: { type: String, required: true },
    subscriptionId: { type: String, required: true },
    cloudProvider: { type: String, required: true },
    serviceName: { type: String, required: true },
    status: { type: String, required: true }
}, {
    timestamps: true,
    versionKey: false
});

mpSubscriptionSchema.index({
    accountId: 1, subscriptionId: 1
}, { unique: true });

const MpSubscription = mongoose.model('mp-subscription', mpSubscriptionSchema);

async function findSubscriptionForProvider(accountId) {
    const result = await MpSubscription.aggregate([
        { $match: { accountId } },
        { $group: { _id: '$cloudProvider', statuses: { $addToSet: '$status' } } },
        {
            $project: {
                provider: '$_id',
                _id: 0,
                status:
                    {
                        $cond:
                            {
                                if: { $in: ['subscribed', '$statuses'] },
                                then: 'subscribed',
                                else: 'unsubscribed'
                            }
                    }
            }
        }]);

    logger.debug('Result subscriptions', result);
    return result;
}

async function findSubscriptionOfAccountIdAndCloudProvider(accountId, cloudProvider) {
    return MpSubscription.find({
        accountId,
        cloudProvider,
        status: SUBSCRIBED
    }).exec();
}

module.exports = { MpSubscription, findSubscriptionForProvider, findSubscriptionOfAccountIdAndCloudProvider };
