const { ApolloError } = require('apollo-server');
const {
    AWS, AZURE, GCP, ONPREM, GCP_REGIONS, AWS_REGIONS, AZURE_LOCATIONS
} = require('../utils/consts');
const { getAccountId } = require('../utils/async-local-storage');
const { getAgentIdByClusterId } = require('./multi-tenancy-operation');
const { getAzureRegions } = require('../lib/agent/azure');
const { getGcpRegions } = require('../lib/agent/gcp');
const { getAwsRegions } = require('../lib/agent/aws');

/*
const getLogger = require('../utils/logger/logger');

const logger = getLogger();
*/

function getRegionByRegionCode(provider, regionCode) {
    switch (provider) {
        case AWS: {
            return { code: regionCode, name: AWS_REGIONS[regionCode] || regionCode };
        }
        case AZURE: {
            return { code: regionCode, name: AZURE_LOCATIONS[regionCode] || regionCode };
        }
        case GCP: {
            return { code: regionCode.toLowerCase(), name: GCP_REGIONS[regionCode.toLowerCase()] || regionCode };
        }
        default: {
            throw new ApolloError(`${provider} cloud provider is not supported`, 400);
        }
    }
}

async function getRegions(provider, regionCode, clusterId, agentIdParam) {
    // because we are trying to hide agentId - we use clusterId and with clusterId we find the agent
    if (!clusterId) {
        throw new ApolloError(`${provider} cloud provider requires clusterId`);
    }
    const agentId = agentIdParam ?? await getAgentIdByClusterId(clusterId, getAccountId());
    switch (provider) {
        case ONPREM:
        case AWS: {
            const regions = await getAwsRegions(agentId);
            return regions.map(region => getRegionByRegionCode(AWS, region));
        }
        case AZURE: {
            const regions = await getAzureRegions(agentId);
            return regions.map(region => ({ name: region.displayName, code: region.name }));
        }
        case GCP: {
            const regions = await getGcpRegions(agentId);
            return regions.map(region => getRegionByRegionCode(GCP, region));
        }
        default: {
            throw new ApolloError(`${provider} cloud provider is not supported`, 400);
        }
    }
}

function isRegionInChina(regionName) {
    return regionName.includes('cn-north');
}

module.exports = { getRegions, getRegionByRegionCode, isRegionInChina };
