const {
    AWS_US_EAST_1_REGION_NAME, AWS_CHINE_REGION_ENDPOINT_SUFFIX, AWS_IC_CLOUD_REGION_NAME, AZURE_BLOB_GERMANY_REGION_ENDPOINT, AZURE_BLOB_CHINA_REGION_ENDPOINT, AZURE_BLOB_GOV_REGION_ENDPOINT, AZURE_BLOB_PUBLIC_REGION_ENDPOINT
} = require('../utils/consts');
const { isRegionInChina } = require('./regions-operations');

function blobStorageEndpointByRegion(region) {
    if (region.toLowerCase().includes('germanycentral') || region.toLowerCase().includes('germanynortheast')) {
        return AZURE_BLOB_GERMANY_REGION_ENDPOINT;
    }
    if (region.toLowerCase().includes('china')) {
        return AZURE_BLOB_CHINA_REGION_ENDPOINT;
    }
    if (region.toLowerCase().includes('usgov') || region.toLowerCase().includes('usdod')) {
        return AZURE_BLOB_GOV_REGION_ENDPOINT;
    }
    return AZURE_BLOB_PUBLIC_REGION_ENDPOINT;
}

function s3EndpointByRegion(region) {
    switch (region) {
        case AWS_US_EAST_1_REGION_NAME: {
            return 's3.amazonaws.com';
        }
        case AWS_IC_CLOUD_REGION_NAME: {
            return 's3.us-iso-east-1.c2s.ic.gov';
        }// TODO: can we deploy bucket in ic?
        default: {
            return isRegionInChina(region) ? `s3.${region}${AWS_CHINE_REGION_ENDPOINT_SUFFIX}` : `s3-${region}.amazonaws.com`;
        }
    }
}

module.exports = {
    s3EndpointByRegion, blobStorageEndpointByRegion
};
