const express = require('express');
const { Account } = require('../models/account');
const { getAccounts } = require('../lib/cloud-manager/multi-tenancy');
const { findTieringStats } = require('../operations/cluster-operations');
const { findAccount } = require('../operations/multi-tenancy-operation');
const { getAccountId } = require('../utils/async-local-storage');
const getLogger = require('../utils/logger/logger');

const logger = getLogger();

const statisticsRoute = express.Router();

statisticsRoute.get('/statistics/account-exists', async (req, res, next) => {
    try {
        const accounts = await getAccounts();
        const accountIds = accounts.map(account => account.accountPublicId);
        logger.info(`Checking if one of the following accounts exist: ${JSON.stringify(accountIds)}`);
        const localAccount = await Account.findOne({ accountId: { $in: accountIds } }).exec();
        res.json(Boolean(localAccount));
    } catch (err) {
        next(err);
    }
});

statisticsRoute.get('/statistics', async (req, res, next) => {
    try {
        const accountId = await findAccount(getAccountId());
        const stats = await findTieringStats(accountId);
        res.json(stats);
    } catch (err) {
        next(err);
    }
});

module.exports = statisticsRoute;
