const config = require('config');

// regions
const GCP_REGIONS = {
    'northamerica-northeast1': 'Canada (Montr\u00E9al)',
    'us-central1': 'US Central (Iowa)',
    'us-east1': 'US East (South Carolina)',
    'us-east4': 'US East (Northern Virginia)',
    'us-west1': 'US West (Oregon)',
    'us-west2': 'US West (Los Angeles)',
    'southamerica-east-1': 'South America (S\u00E3o Paulo)',
    'europe-north1': 'EU West (Finland)',
    'europe-west1': 'EU West (Belgium)',
    'europe-west2': 'EU West (London)',
    'europe-west3': 'EU West (Frankfurt)',
    'europe-west4': 'EU West (Netherlands)',
    'europe-west6': 'EU West (Zürich)',
    'asia-east1': 'Asia East (Taiwan)',
    'asia-east2': 'Asia East (Hong Kong)',
    'asia-northeast1': 'Asia North-East (Tokyo)',
    'asia-northeast2': 'Asia North-East (Osaka)',
    'asia-south1': 'Asia South (Mumbai)',
    'asia-southeast1': 'Asia South-East (Singapore)',
    'australia-southeast1': 'Australia (Sydney)',
    asia: 'Asia',
    eu: 'EU',
    us: 'US'
};
const AWS_REGIONS = {
    'us-east-2': 'US East (Ohio)',
    'us-east-1': 'US East (N. Virginia)',
    'us-west-1': 'US West (N. California)',
    'us-west-2': 'US West (Oregon)',
    'ap-south-1': 'Asia Pacific (Mumbai)',
    'ap-northeast-3': 'Asia Pacific (Osaka-Local)',
    'ap-northeast-2': 'Asia Pacific (Seoul)',
    'ap-southeast-1': 'Asia Pacific (Singapore)',
    'ap-southeast-2': 'Asia Pacific (Sydney)',
    'ap-northeast-1': 'Asia Pacific (Tokyo)',
    'ca-central-1': 'Canada (Central)',
    'cn-north-1': 'China (Beijing)',
    'cn-northwest-1': 'China (Ningxia)',
    'eu-central-1': 'EU (Frankfurt)',
    'eu-west-1': 'EU (Ireland)',
    'eu-west-2': 'EU (London)',
    'eu-west-3': 'EU (Paris)',
    'eu-north-1': 'EU (Stockholm)',
    'sa-east-1': 'South America (São Paulo)',
    'us-gov-east-1': 'AWS GovCloud (US-East)',
    'us-gov-west-1': 'AWS GovCloud (US)',
    'me-south-1': 'Middle East (Bahrain)',
    'ap-east-1': 'Asia Pacific (Hong Kong)',
    US: 'US East (N. Virginia)'
};
const AZURE_LOCATIONS = {
    eastasia: 'East Asia',
    southeastasia: 'Southeast Asia',
    centralus: 'Central US',
    eastus: 'East US',
    eastus2: 'East US 2',
    westus: 'West US',
    northcentralus: 'North Central US',
    southcentralus: 'South Central US',
    northeurope: 'North Europe',
    westeurope: 'West Europe',
    japanwest: 'Japan West',
    japaneast: 'Japan East',
    brazilsouth: 'Brazil South',
    australiaeast: 'Australia East',
    australiasoutheast: 'Australia Southeast',
    canadacentral: 'Canada Central',
    canadaeast: 'Canada East',
    uksouth: 'UK South',
    ukwest: 'UK West',
    westcentralus: 'West Central US',
    westus2: 'West US 2',
    koreacentral: 'Korea Central',
    koreasouth: 'Korea South',
    francecentral: 'France Central'
};

// DB connection
const DB_CONNECTION_STRING = process.env.DB_CONNECTION_STRING || config.get('db-connection-string');

// AGENDA
const AGENDA_PROCESS_EVERY = '300 seconds';
const AGENDA_JOB_NAME_SAAS_METERING = 'CHARGING';
const AGENDA_JOB_NAME_TRIAL_EXPIRY_STATUS = 'TRIAL_EXPIRY_STATUS';
const AGENDA_JOB_NAME_INCREASE_LICENSE_CAPACITY = 'INCREASE_LICENSE_CAPACITY';
const AGENDA_JOB_NAME_UPDATE_CLUSTERS_COLLECTION = 'UPDATE_CLUSTERS_COLLECTION';
const AGENDA_JOB_NAME_BACKUP_DB = 'BACKUP_DB';
const AGENDA_JOB_UPDATE_BYOL_LICENSES_CAPACITY = 'UPDATE_BYOL_LICENSES_CAPACITY';

// subscription and charging
// subscription statuses
const SUBSCRIBED = 'subscribed';
const UNSUBSCRIBED = 'unsubscribed';
const FAILED_SUBSCRIPTION = 'failed';
const UNSUBSCRIBE_PENDING = 'unsubscribe-pending';
const PENDING_SUBSCRIPTION = 'pending';
const SUSPEND_SUBSCRIPTION = 'suspended'; // azure has suspended status
// on aws - production coud-tiering subscription is different from dev
// on azure its the same
// on gcp we use occm serviceName
const TIERING_SERVICE_NAME_SUBSCRIPTION = config.get('charging.charging-service-name') || 'cloud-tiering'; // for tests
const TIERING_AZURE_SERVICE_NAME_SUBSCRIPTION = 'cloud-tiering'; // for testing and production
const OCCM_SERVICE_NAME_SUBSCRIPTION = 'cloud-volumes-ontap';
const CHARGING_DIMENSION = config.get('charging.charging-dimension');
const OCCM_CHARGING_DIMENSION = 'cloud_tiering'; // relevant for AWS OCCM subscription and TIERING AZURE subscription
const AZURE_OCCM_CHARGING_DIMENSION = 'tiering';
const GCP_CHARGING_DIMENSION = config.get('charging.gcp-charging-dimesion');
const FREE_TRIAL_DAYS = 30;

// Endpoints
const MULTI_TENANCY_ENDPOINT = process.env.MULTI_TENANCY_ENDPOINT ? `http://${process.env.MULTI_TENANCY_ENDPOINT}` : config.get('services-urls.tenancy');
const AGENTS_MGMT_ENDPOINT = process.env.AGENTS_MGMT_ENDPOINT ? `http://${process.env.AGENTS_MGMT_ENDPOINT}` : config.get('services-urls.agents');
const CLOUD_MANAGER_ENDPOINT = process.env.CLOUD_MANAGER_ENDPOINT ? `http://${process.env.CLOUD_MANAGER_ENDPOINT}` : config.get('services-urls.occm');
const SUBSCRIPTION_ENDPOINT = process.env.SUBSCRIPTION_ENDPOINT ? `https://${process.env.SUBSCRIPTION_ENDPOINT}` : config.get('services-urls.subscription');
const CHARGING_ENDPOINT = process.env.CHARGING_ENDPOINT ? `http://${process.env.CHARGING_ENDPOINT}` : config.get('services-urls.charging');
const AGENT_ENDPOINT = process.env.CONTAINER_MANAGER_ENDPOINT ? `http://${process.env.CONTAINER_MANAGER_ENDPOINT}` : config.get('services-urls.agent');

// BACKUP DETAILS
const BACKUP_BUCKET = config.get('backup.bucket');
const { BACKUP_AWS_ACCESS_KEY, BACKUP_AWS_SECRET_KEY } = process.env;

// locations
const ONPREM_DISCOVER_LOCATION = 'ON_PREM';
const DISCOVER_LOCATION = 'CLOUD_TIERING';
const OCCM_LOCATION = 'OCCM';
const VSA = 'VSA';
const CVO = 'CVO';

const RESOURCE_TYPE_CONVERTER = {
    [ONPREM_DISCOVER_LOCATION]: ONPREM_DISCOVER_LOCATION,
    [VSA]: VSA,
    [DISCOVER_LOCATION]: ONPREM_DISCOVER_LOCATION
};

// apis
// new agent
const AGENT_API_PREFIX = '/account/';
const AGENT_API_PROVIDERS_PREFIX = '/providers/cloudmanager_tiering/api';
const AGENT_LIST_GCP_BUCKETS = '/gcp/buckets';
const AGENT_LIST_GCP_REGIONS = '/gcp/regions';
const AGENT_SET_GCP_STORAGE_CLASS = '/gcp/buckets/storage-class';
const AGENT_LIST_AWS_REGIONS = '/aws/regions';
const AGENT_LIST_AWS_BUCKETS = '/aws/buckets';
const AGENT_GET_AWS_STORAGE_CLASS = '/aws/buckets/storage-class';
const AGENT_LIST_AZURE_REGIONS = '/azure/locations';
const AGENT_LIST_AZURE_SUBSCRIPTIONS = '/azure/subscriptions';
const AGENT_LIST_AZURE_ALL_STORAGE_ACCOUNTS = '/azure/all-storage-accounts';
const AGENT_LIST_AZURE_STORAGE_ACCOUNTS = '/azure/storage-accounts';
const AGENT_LIST_AZURE_RESOURCE_GROUPS = '/azure/resource-groups';
const AGENT_LIST_AZURE_STORAGE_ACCOUNT_KEYS = '/azure/storage-account-keys';
const AGENT_LIST_AZURE_CONTAINERS = '/azure/blob-containers';
const AGENT_CHANGE_AZURE_STORAGE_ACCOUNT_TIER_LEVEL = '/azure/storage-account-tier-level';
const AGENT_ZAPI_PATH = '/zapi/';
const AGENT_DESCRIBE_AGGREGATES_PATH = '/aggregates';
const AGENT_DESCRIBE_OBJECT_STORES_PATH = '/object-stores';
const AGENT_DESCRIBE_SYSTEM_IMAGES_PATH = '/nodes-system-images';
const AGENT_DESCRIBE_SVMS_PATH = '/svms';
const AGENT_CLUSTER_INFO_PATH = '/cluster-info';
const AGENT_DESCRIBE_NODES_PATH = '/nodes';
const AGENT_DESCRIBE_SVM_VOLUMES_PATH = '/volumes';
const AGENT_DESCRIBE_CLUSTER_VOLUME_FOOTPRINT_PATH = '/cluster-volumes-foot-print';
const AGENT_DESCRIBE_VOLUME_MINIMUM_COOLING_DAYS_PATH = '/volume-minimum-cooling-days';
const AGENT_DESCRIBE_LIFS_PATH = '/svm-lifs';
const AGENT_DESCRIBE_ONTAP_VERSION_PATH = '/ontap-version';
const AGENT_ZAPI_DESCRIBE_ONTAP_VERSION_PATH = '/zapi/ontap-version';
const AGENT_DESCRIBE_OBJECTSTORE_CONFIG_PATH = '/object-store-configs';
const AGENT_DESCRIBE_AWS_STORAGE_CLASS_PATH = '/bucket/storageClass';
const AGENT_LICENSES_PATH = '/licenses-v2';
const AGENT_ENABLE_COLD_DATA_REPORTING_PATH = '/cold-data-reporting';
const AGENT_MODIFY_VOLUME_MINIMUM_COOLING_DAYS_PATH = '/volume-minimum-cooling-days';
const AGENT_MODIFY_TIERING_FULLNESS_THRESHOLD_PATH = '/tiering-fullness-threshold';
const AGENT_SGWS_PATH = '/sgws/';
const AGENT_LIST_SGWS_BUCKETS = '/sgws/buckets';
const AGENT_CREATE_SGWS_BUCKET = '/sgws/bucket';
const AGENT_PUT_OBJECT_SGWS = '/sgws/bucketId/object';

const CLOUD_MANAGER_API_PREFIX = '/occm/api';
const CLOUD_MANAGER_CLUSTERS_PATH_PREFIX = '/onprem/working-environments';

const OCCM_BASE_URL = `${CLOUD_MANAGER_ENDPOINT}${CLOUD_MANAGER_API_PREFIX}`;

const SUBSCRIPTION_API_PREFIX = '/subscriptions';
const SUBSCRIPTION_BASE_URL = `${SUBSCRIPTION_ENDPOINT}${SUBSCRIPTION_API_PREFIX}`;

const CHARGING_API_PREFIX = '/charging';
const CHARGING_BASE_URL = `${CHARGING_ENDPOINT}${CHARGING_API_PREFIX}`;

const API_PATH_TENANTS = '/tenants';
const API_PATH_ACCOUNTS = '/tenancy/external/account';
const API_PATH_AGENTS = '/agents-mgmt/external/agent';
const API_PATH_AGENTS_INTERNAL = '/agents-mgmt/internal';
const API_PATH_RESOURCES = '/tenancy/external/resource';
const API_PATH_RESOURCES_INTERNAL = '/tenancy/internal/resource';
const API_PATH_USERS_OF_ACCOUNT_INTERNAL = '/tenancy/internal/users/users-by-account-id';

// auth0
const JWT_TOKEN_AUTH0 = config.get('auth0-url');
const JWT_TOKEN_CLOUD_MANAGER_AUDIENCE = 'https://cloudmanager.cloud.netapp.com';
const JWR_TOKEN_TENANCY_AUDIENCE = 'https://api.cloud.netapp.com';
const CLIENT_ID = process.env.CLIENT_ID || config.get('client_id');
const CLIENT_SECRET = process.env.CLIENT_SECRET || config.get('client_secret');

// ipa
const IPA_STAGING_BASE_URL = 'https://stagesupport.netapp.com/ServiceGW';
const IPA_LICENSE_OPERATIONS_PATH = '/entitlement/prodstatus/v6';
const IPA_LICENSE_REGISTRATION_URL = config.get('ipa.license-registration');
const IPA_BASE_URL = 'https://support.netapp.com/ServiceGW';
const IPA_SIGN_PATH = '/signMessage';
const SIGNED_SERVICE_USER_NAME = process.env.SIGNED_SERVICE_USER_NAME || config.get('signed_service_user_name');
const SIGNED_SERVICE_PASSWORD = process.env.SIGNED_SERVICE_PASSWORD || config.get('signed_service_password');
const IPA_LOOKUP_TOKEN_URL = config.get('ipa.license-lookup-token-url');
const IPA_LOOKUP_URL = config.get('ipa.license-lookup-url');

const API_ROOT = '/api';
const GRAPHQL_ROOT = '/graphql';
const API_PATH_SAAS_SUBSCRIPTION_NOTIFICATION = '/mp-subscription';
const API_PATH_HEALTH = '/health';

const SAVING_OPPORTUNITY_ESTIMATION_RATIO = 0.7;
// cloud providers
const AWS = 'AWS';
const ONPREM = 'ONPREM';
const AZURE = 'AZURE';
const GCP = 'GCP';
const SGWS = 'SGWS';
const CLOUD_PROVIDERS = {
    [AZURE]: 'azure',
    [AWS]: 'aws',
    [GCP]: 'gcp'
};
const OCCM_PROVIDER_TO_CLOUD_PROVIDER = {
    aws_s3: AWS,
    azure_cloud: AZURE,
    googlecloud: GCP,
    sgws: SGWS
};
const CLOUD_PROVIDER_TO_OCCM_PROVIDER = {
    [AWS]: 'aws_s3',
    [AZURE]: 'azure_cloud',
    [GCP]: 'googlecloud',
    [SGWS]: 'sgws'
};
// tiering policy
const SNAPSHOT_ONLY = 'snapshot_only';
const AUTO = 'auto';
const NONE = 'none';
const BACKUP = 'backup';
const ALL = 'all';

const TIERING_POLICIES_AND_MINIMUM_COOLING_DAYS = {
    [AUTO]: 31,
    [SNAPSHOT_ONLY]: 2
};

const DP_VOLUME = 'dp';
const ONLINE_VOLUME = 'online';

const OBJECT_STORE_AVAILABLE_STATE = 'available';
const OBJECT_STORE_UNAVAILABLE_STATE = 'unavailable';

// GCP STORAGE CLASS
const NEARLINE = 'nearline';
const COLDLINE = 'coldline';
const ARCHIVE = 'archive';
const STANDARD = 'standard';
const MULTI_REGION = 'multi_regional';
const REGIONAL = 'regional';

// AWS STORAGE CLASS
const STANDARD_IA = 'STANDARD_IA';
const ONE_ZONE_IA = 'ONEZONE_IA';
const INTELLIGENT = 'INTELLIGENT_TIERING';
const STANDARD_AWS = 'STANDARD';

// AZURE STORAGE CLASS
const HOT = 'Hot';
const COOL = 'Cool';

const ONTAP_VERSIONS_FEATURES_SUPPORT = {
    ENABLE_COLD_DATA_REPORTING: 9.4,
    FLEX_GROUP: 9.5,
    MINIMUM_COOLING_DAYS: 9.4,
    TIERING_FULLNESS_THRESHOLD: 9.5,
    OBJECT_STORES: 9.2
};

const STORAGE_CLASSES_NEW_AGENT = {
    AWS: {
        intelligent: INTELLIGENT,
        standard_ia: STANDARD_IA,
        ia_single: ONE_ZONE_IA,
        standard: STANDARD_AWS,
        [INTELLIGENT]: 'intelligent',
        [STANDARD_IA]: 'standard_ia',
        [ONE_ZONE_IA]: 'ia_single',
        [STANDARD_AWS]: 'standard'
    },
    AZURE: {
        cool: COOL,
        hot: HOT,
        [COOL]: 'cool',
        [HOT]: 'hot'
    }
};

const FAS_AFF_NODE_MODELS = [
    'AFF-A800', 'AFF-A700S', 'AFF-A700', 'AFF-A600', 'AFF-A400', 'AFF-A320', 'AFF-A300', 'AFF-A220', 'AFF-A200', 'AFF-C190', 'AFF8080', 'AFF8060', 'AFF8040',
    'FAS9000', 'FAS8700', 'FAS8300', 'FAS8200', 'FAS8080', 'FAS8060', 'FAS8040', 'FAS2750', 'FAS2720', 'FAS2650', 'FAS2620', 'FAS2520', 'FAS2552', 'FAS2554'];

const WHITELIST_VSIM_IP_E2E = ['10.68.128.225', '10.68.128.219', '10.68.128.210', '10.68.128.229'];

const WHITELIST_CVO_NAMES_PREFIX_E2E = ['gcpcvotieringproduction', 'azurecvotieringproduction', 'awscvotieringproduction'];

// cluster statuses
const NO_TIERING_STATUS = 'NO_TIERING';
const ON_STATUS = 'ON';
const UNKNOWN_STATUS = 'UNKNOWN';
const FAILED_STATUS = 'FAILED';

// agents statuses
const AGENT_ACTIVE_STATUS = 'active';
const AGENT_PENDING_STATUS = 'pending';
const AGENT_INACTIVE_STATUS = 'inactive';
const AGENT_UNKNOWN_STATUS = 'unknown';

const OBJECT_STORAGE_CONFIG_NAME_PREFIX = 'OSC-CT';

// regions
const AWS_IC_CLOUD_REGION_NAME = 'us-iso-east-1';
const AWS_US_EAST_1_REGION_NAME = 'us-east-1';
const AWS_CHINE_REGION_ENDPOINT_SUFFIX = '.amazonaws.com.cn';

const AZURE_BLOB_GERMANY_REGION_ENDPOINT = 'blob.core.cloudapi.de';
const AZURE_BLOB_PUBLIC_REGION_ENDPOINT = 'blob.core.windows.net';
const AZURE_BLOB_CHINA_REGION_ENDPOINT = 'blob.core.chinacloudapi.cn';
const AZURE_BLOB_GOV_REGION_ENDPOINT = 'blob.core.usgovcloudapi.net';

const GCP_STORAGE_ENDPOINT = 'storage.googleapis.com';

// events
const UPDATE_LICENSE_INFO_EVENT = 'UPDATE LICENSE INFO';
const UPDATE_CLUSTERS_INFO_EVENT = 'UPDATE CLUSTER INFO';
const UPDATE_CLUSTER_INFO_EVENT = 'UPDATE CLUSTER';

const DEFAULT_AWS_REGION = 'us-east-1';

const HUBSPOT_FIELDS = {
    list_buckets: 'ct_list_buckets',
    create_bucket: 'ct_create_bucket',
    permission_check: 'ct_permission_check',
    object_store_config: 'ct_object_store_config_create',
    modify_volume: 'ct_modify_volume_policy_change',
    subscribe: 'ct_subscribe',
    failed: 'ct_failure',
    discoverStatus: 'ct_discover_status'
};

module.exports = {
    SUBSCRIBED,
    UNSUBSCRIBED,
    MULTI_TENANCY_ENDPOINT,
    CLOUD_MANAGER_ENDPOINT,
    CLOUD_MANAGER_CLUSTERS_PATH_PREFIX,
    API_ROOT,
    API_PATH_TENANTS,
    API_PATH_SAAS_SUBSCRIPTION_NOTIFICATION,
    API_PATH_RESOURCES,
    API_PATH_RESOURCES_INTERNAL,
    API_PATH_AGENTS_INTERNAL,
    API_PATH_USERS_OF_ACCOUNT_INTERNAL,
    IPA_SIGN_PATH,
    JWT_TOKEN_CLOUD_MANAGER_AUDIENCE,
    API_PATH_ACCOUNTS,
    IPA_BASE_URL,
    API_PATH_AGENTS,
    CLOUD_MANAGER_API_PREFIX,
    AGENDA_PROCESS_EVERY,
    AGENDA_JOB_NAME_SAAS_METERING,
    AGENDA_JOB_NAME_INCREASE_LICENSE_CAPACITY,
    AGENDA_JOB_NAME_UPDATE_CLUSTERS_COLLECTION,
    AGENDA_JOB_NAME_BACKUP_DB,
    AGENTS_MGMT_ENDPOINT,
    GRAPHQL_ROOT,
    DISCOVER_LOCATION,
    DB_CONNECTION_STRING,
    API_PATH_HEALTH,
    SAVING_OPPORTUNITY_ESTIMATION_RATIO,
    JWR_TOKEN_TENANCY_AUDIENCE,
    CLIENT_ID,
    CLIENT_SECRET,
    JWT_TOKEN_AUTH0,
    SIGNED_SERVICE_USER_NAME,
    SIGNED_SERVICE_PASSWORD,
    OCCM_BASE_URL,
    CLOUD_PROVIDERS,
    SNAPSHOT_ONLY,
    AUTO,
    NONE,
    BACKUP,
    ALL,
    AWS,
    AZURE,
    GCP,
    ONPREM,
    SGWS,
    HOT,
    SUBSCRIPTION_ENDPOINT,
    TIERING_SERVICE_NAME_SUBSCRIPTION,
    CHARGING_ENDPOINT,
    FAILED_SUBSCRIPTION,
    UNSUBSCRIBE_PENDING,
    PENDING_SUBSCRIPTION,
    OCCM_PROVIDER_TO_CLOUD_PROVIDER,
    FREE_TRIAL_DAYS,
    CHARGING_DIMENSION,
    SUBSCRIPTION_BASE_URL,
    CHARGING_BASE_URL,
    CHARGING_API_PREFIX,
    DP_VOLUME,
    ONLINE_VOLUME,
    SUBSCRIPTION_API_PREFIX,
    AGENDA_JOB_NAME_TRIAL_EXPIRY_STATUS,
    OBJECT_STORE_AVAILABLE_STATE,
    OBJECT_STORE_UNAVAILABLE_STATE,
    ONPREM_DISCOVER_LOCATION,
    OCCM_LOCATION,
    NO_TIERING_STATUS,
    ON_STATUS,
    UNKNOWN_STATUS,
    UPDATE_LICENSE_INFO_EVENT,
    UPDATE_CLUSTERS_INFO_EVENT,
    OCCM_SERVICE_NAME_SUBSCRIPTION,
    TIERING_AZURE_SERVICE_NAME_SUBSCRIPTION,
    OCCM_CHARGING_DIMENSION,
    GCP_CHARGING_DIMENSION,
    SUSPEND_SUBSCRIPTION,
    AGENT_ACTIVE_STATUS,
    AGENT_PENDING_STATUS,
    AGENT_INACTIVE_STATUS,
    AGENT_UNKNOWN_STATUS,
    FAILED_STATUS,
    BACKUP_AWS_SECRET_KEY,
    BACKUP_AWS_ACCESS_KEY,
    BACKUP_BUCKET,
    DEFAULT_AWS_REGION,
    OBJECT_STORAGE_CONFIG_NAME_PREFIX,
    AWS_IC_CLOUD_REGION_NAME,
    AWS_US_EAST_1_REGION_NAME,
    AWS_CHINE_REGION_ENDPOINT_SUFFIX,
    AZURE_BLOB_GERMANY_REGION_ENDPOINT,
    AZURE_BLOB_CHINA_REGION_ENDPOINT,
    AZURE_BLOB_PUBLIC_REGION_ENDPOINT,
    AZURE_BLOB_GOV_REGION_ENDPOINT,
    GCP_STORAGE_ENDPOINT,
    CLOUD_PROVIDER_TO_OCCM_PROVIDER,
    FAS_AFF_NODE_MODELS,
    WHITELIST_CVO_NAMES_PREFIX_E2E,
    WHITELIST_VSIM_IP_E2E,
    HUBSPOT_FIELDS,
    VSA,
    CVO,
    TIERING_POLICIES_AND_MINIMUM_COOLING_DAYS,
    AGENT_LIST_GCP_BUCKETS,
    AGENT_API_PREFIX,
    AGENT_API_PROVIDERS_PREFIX,
    AGENT_LIST_GCP_REGIONS,
    NEARLINE,
    COLDLINE,
    ARCHIVE,
    AGENT_SET_GCP_STORAGE_CLASS,
    GCP_REGIONS,
    AWS_REGIONS,
    AZURE_LOCATIONS,
    AGENT_LIST_AWS_REGIONS,
    AGENT_LIST_AWS_BUCKETS,
    STANDARD,
    MULTI_REGION,
    REGIONAL,
    STANDARD_IA,
    ONE_ZONE_IA,
    INTELLIGENT,
    STANDARD_AWS,
    AGENT_LIST_AZURE_CONTAINERS,
    STORAGE_CLASSES_NEW_AGENT,
    AGENT_LIST_AZURE_STORAGE_ACCOUNT_KEYS,
    AGENT_CHANGE_AZURE_STORAGE_ACCOUNT_TIER_LEVEL,
    AGENT_ENDPOINT,
    AGENT_LIST_AZURE_REGIONS,
    AGENT_LIST_AZURE_SUBSCRIPTIONS,
    AGENT_LIST_AZURE_ALL_STORAGE_ACCOUNTS,
    AGENT_DESCRIBE_AGGREGATES_PATH,
    AGENT_ZAPI_PATH,
    AGENT_DESCRIBE_OBJECT_STORES_PATH,
    AGENT_DESCRIBE_NODES_PATH,
    AGENT_DESCRIBE_SYSTEM_IMAGES_PATH,
    AGENT_DESCRIBE_SVMS_PATH,
    AGENT_CLUSTER_INFO_PATH,
    AGENT_DESCRIBE_VOLUME_MINIMUM_COOLING_DAYS_PATH,
    AGENT_DESCRIBE_SVM_VOLUMES_PATH,
    AGENT_DESCRIBE_ONTAP_VERSION_PATH,
    AGENT_DESCRIBE_CLUSTER_VOLUME_FOOTPRINT_PATH,
    AGENT_DESCRIBE_LIFS_PATH,
    AGENT_GET_AWS_STORAGE_CLASS,
    AGENT_DESCRIBE_OBJECTSTORE_CONFIG_PATH,
    AGENT_DESCRIBE_AWS_STORAGE_CLASS_PATH,
    AGENT_ZAPI_DESCRIBE_ONTAP_VERSION_PATH,
    ONTAP_VERSIONS_FEATURES_SUPPORT,
    AGENT_LICENSES_PATH,
    AGENT_MODIFY_VOLUME_MINIMUM_COOLING_DAYS_PATH,
    AGENT_ENABLE_COLD_DATA_REPORTING_PATH,
    AGENT_LIST_SGWS_BUCKETS,
    AGENT_SGWS_PATH,
    AGENT_PUT_OBJECT_SGWS,
    AGENT_CREATE_SGWS_BUCKET,
    AGENT_MODIFY_TIERING_FULLNESS_THRESHOLD_PATH,
    RESOURCE_TYPE_CONVERTER,
    AZURE_OCCM_CHARGING_DIMENSION,
    UPDATE_CLUSTER_INFO_EVENT,
    AGENT_LIST_AZURE_RESOURCE_GROUPS,
    AGENT_LIST_AZURE_STORAGE_ACCOUNTS,
    IPA_STAGING_BASE_URL,
    IPA_LICENSE_OPERATIONS_PATH,
    IPA_LICENSE_REGISTRATION_URL,
    IPA_LOOKUP_TOKEN_URL,
    IPA_LOOKUP_URL,
    AGENDA_JOB_UPDATE_BYOL_LICENSES_CAPACITY
};
