const { ApolloError } = require('apollo-server');
const randomize = require('randomatic');
const bytes = require('bytes');
const crypto = require('crypto');
const { isEmpty, trim } = require('lodash');
const {
    AGENT_API_PREFIX, AGENT_ENDPOINT, AGENT_API_PROVIDERS_PREFIX
} = require('./consts');
const { getServiceToken } = require('../lib/auth0');
const {
    getUserToken, getRequestId, getAccountId, getSendAudit
} = require('./async-local-storage');

const algorithm = 'aes-128-cbc';
const notEncryptedEncoding = 'utf8';
const encryptedEncoding = 'hex';
const key = Buffer.from('5ebe2294ecd0e0f08eab7690d2a6ee69', encryptedEncoding);
const iv = Buffer.from('26ae5cc854e36b6bdfca366848dea6bb', encryptedEncoding);

function capacityToBytes(capacity) {
    return capacity ? bytes(`${capacity.size}${capacity.unit}`) : 0;
}

function bytesToCapacity(bytess) {
    const sizeString = bytes(bytess);
    const regexPattern = /(\d+\.{0,1}\d*)(\S+)/;
    const match = regexPattern.exec(sizeString);
    if (match) {
        const [, size, unit] = match;
        return { size: parseFloat(size), unit };
    }
    throw new Error(`Failed to parse ${sizeString} to size and unit`);
}

function encryptPassword(password) {
    const cipher = crypto.createCipheriv(algorithm, key, iv);
    let crypted = cipher.update(password, notEncryptedEncoding, encryptedEncoding);
    crypted += cipher.final(encryptedEncoding);
    return crypted;
}

function decryptPassword(password) {
    const decipher = crypto.createDecipheriv(algorithm, key, iv);
    let dec = decipher.update(password, encryptedEncoding, notEncryptedEncoding);
    dec += decipher.final(notEncryptedEncoding);
    return dec;
}

function isEmptyString(str) {
    return isEmpty(trim(str));
}

function generateRequestId() {
    return `CT-${randomize('Aa0', 8)}`;
}

function checkEnvironment(env) {
    return process.env.NODE_ENV === env;
}

function getHeaders() {
    return {
        authorization: getUserToken() || getServiceToken(),
        'X-Request-Id': randomize('0', 8),
        'X-Service-Request-Id': getRequestId() || generateRequestId(),
        'X-Tenancy-Account-Id': getAccountId() || 'system'
    };
}

function createHeadersForAgent(agentId, headersToAdd) {
    return {
        headers: {
            ...getHeaders(),
            'X-Agent-Id': agentId,
            'Send-Audit': getSendAudit() || false,
            ...headersToAdd
        }
    };
}

function createHeaders(headersToAdd) {
    const headers = {
        ...getHeaders(),
        ...headersToAdd
    };
    return {
        headers
    };
}

function createAgentPath(path, accountId) {
    const requestedAccountId = accountId || getAccountId();
    return `${AGENT_ENDPOINT}${AGENT_API_PREFIX}${requestedAccountId}${AGENT_API_PROVIDERS_PREFIX}${path}`;
}

function verifyRequestParams(cloudProvider, rest) {
    if (!rest[cloudProvider.toLowerCase()]) {
        throw new ApolloError(`Please add ${cloudProvider.toLowerCase()} object to the request`, 403);
    }
}

module.exports = {
    verifyRequestParams,
    createAgentPath,
    capacityToBytes,
    encryptPassword,
    decryptPassword,
    bytesToCapacity,
    isEmptyString,
    generateRequestId,
    checkEnvironment,
    createHeaders,
    createHeadersForAgent
};
