const { validateResponse } = require('../../../src/utils/schema-validation');
const { aggregatesResponse, volumesResponseSchema, licenseStatusResponseSchema } = require('../../../src/joi-schemas/agent-schemas');

describe('validate agent-zapi response schemas', () => {
    test('successfully validate describeAggregates response', () => {
        const validDescribeAggregatesResponse = [{
            name: 'aggr-2',
            state: 'up',
            isRoot: false,
            isInactiveDataReportingEnabled: true,
            isObjectStoreAttachEligible: false,
            usedCapacity: 1099511627776,
            totalCapacity: 10995116277760,
            isComposite: true
        }];
        expect(validateResponse(validDescribeAggregatesResponse, aggregatesResponse)).not.toBeDefined();
    });

    test('successfully validate empty describe volumes response', () => {
        expect(validateResponse([], volumesResponseSchema)).not.toBeDefined();
    });

    test('successfully validate fabric pool license status', () => {
        const licenseStatusValid = [{
            serialNumber: '123',
            package: 'fabricpool',
            maxCapacity: 1000,
            currentCapacity: 1222
        }];
        expect(validateResponse(licenseStatusValid, licenseStatusResponseSchema)).not.toBeDefined();
    });

    test('successfully validate describe volumes response', () => {
        const volumesValid = [{
            name: 'vol',
            isVserverRoot: true,
            svmName: 'svm_onprem',
            sizeTotal: 10,
            usedSize: 5,
            tierInactiveUserData: 2,
            tierInactiveUserDataPercent: 40,
            tieringPolicy: 'auto',
            aggregateName: 'aggr1',
            volumeType: 'rw'
        }];
        expect(validateResponse(volumesValid, volumesResponseSchema)).not.toBeDefined();
    });
    test('successfully validate volumes with tiering policy null', () => {
        const volumesNoTieringPolicy = [{
            name: 'vol',
            svmName: 'svm_onprem',
            sizeTotal: 10,
            usedSize: 5,
            tierInactiveUserData: null,
            tierInactiveUserDataPercent: null,
            tieringPolicy: null,
            aggregateName: 'aggr1',
            volumeType: 'rw'
        }];

        expect(validateResponse(volumesNoTieringPolicy, volumesResponseSchema)).not.toBeDefined();
    });
});
