const nock = require('nock');
const { IPA_LOOKUP_URL } = require('../../../src/utils/consts');
const { USERS } = require('../simulator-state');
const { findUserId } = require('../simulator-utils');

const ipaOperationsScope = nock(IPA_LOOKUP_URL)
    .get(/.*/)
    .delay(100)
    .reply(200, function (uri) {
        const requestURL = new URL(uri, IPA_LOOKUP_URL);
        const serialNumber = requestURL.searchParams.get('serialNumber');
        const userId = findUserId(this.req.headers['x-user-id']);
        const byolLicenseResponse = Object.values(USERS[userId].BYOL_LICENSES).find(byolLicense => byolLicense.records.license_record.statusResp.serialNumber === serialNumber);
        return (byolLicenseResponse) || {
            records: {
                license_record: {
                    statusResp: {
                        statusCode: 'ERROR',
                        errorCode: 'E003',
                        message: 'The Serial Number submitted was not found in our systems.  Please ensure the Serial Number is entered correctly and try again.',
                        filter: 'SOA',
                        serialNumber
                    }
                }
            },
            trackingID: 'OntapLicense-stg_saptestuser1_08262020091726',
            totalRecords: '0'
        };
    });

ipaOperationsScope.persist(true);

module.exports = ipaOperationsScope;
