const { URL } = require('url');
const got = require('got');
const nock = require('nock');
const { last } = require('lodash');
const { validateSchema } = require('../../../src/utils/schema-validation');
const { subscriptionSchema } = require('../../../src/joi-schemas/subscription-schemas');
const {
    SUBSCRIPTION_ENDPOINT, SUBSCRIPTION_API_PREFIX
} = require('../../../src/utils/consts');
const { escapeForwardSlash, findUserId } = require('../simulator-utils');
const { createScenarioForUser, USERS, SUBSCRIPTIONS } = require('../simulator-state');

const subscriptionServiceScope = nock(SUBSCRIPTION_ENDPOINT)
    // create subscription - fake API for testing
    .post(escapeForwardSlash(`${SUBSCRIPTION_API_PREFIX}/.+`),
        body => {
            try {
                validateSchema(body, subscriptionSchema);
                return true;
            } catch (err) {
                return false;
            }
        })
    .delay(100)
    .reply(function (uri, requestBody) {
        const userId = findUserId(this.req.headers.authorization);
        const requestURL = new URL(uri, SUBSCRIPTION_ENDPOINT);
        const accountId = last(requestURL.pathname.split('/'));
        const subscription = requestBody;
        const {
            subscriptionId, subscriptionStatus, serviceName, cloudProvider, contract
        } = subscription;
        if (!USERS[userId] && !userId.includes('clients')) {
            USERS[userId] = createScenarioForUser(userId);
        }
        // verify there is an account
        if (!USERS[userId].ACCOUNTS[accountId]) {
            return [404, 'account not found'];
        }
        if (SUBSCRIPTIONS.length) {
            const subscriptionFromSubscriptions = SUBSCRIPTIONS.find(sub => sub.subscriptionId === subscriptionId);
            if (subscriptionFromSubscriptions) {
                const { accounts } = subscriptionFromSubscriptions;
                if (accounts && !accounts.find(account => account === accountId)) {
                    subscriptionFromSubscriptions.accounts.push(accountId);
                } else {
                    subscriptionFromSubscriptions.accounts = [accountId];
                }
                subscriptionFromSubscriptions.subscriptionStatus = subscriptionStatus;
            } else {
                subscription.accounts = [accountId];
                SUBSCRIPTIONS.push(subscription);
            }
        } else {
            subscription.accounts = [accountId];
            SUBSCRIPTIONS.push(subscription);
        }
        const updatedSubscription = SUBSCRIPTIONS.find(sub => sub.subscriptionId === subscriptionId);
        if (!process.env.TEST) {
            got.post('http://local.cloudtiering.io/api/mp-subscription/update',
                {
                    resolveBodyOnly: true,
                    responseType: 'json',
                    json: {
                        notificationType: 'add-subscription',
                        subscriptionId,
                        accounts: updatedSubscription ? updatedSubscription.accounts : [],
                        productCode: 'd0j5kpdwz8pdjxpf4q4kvtslb',
                        subscriptionStatus,
                        timestamp: new Date(),
                        serviceName,
                        contract,
                        cloudProvider: cloudProvider.toUpperCase()
                    },
                    headers: { authorization: this.req.headers.authorization }
                });
        }
        return [200, subscription];
    })

    // list subscriptions by service name
    .get(escapeForwardSlash(`${SUBSCRIPTION_API_PREFIX}/by-service-name`))
    .query(query => query.serviceName)
    .delay(100)
    .reply(uri => {
        const requestURL = new URL(uri, SUBSCRIPTION_ENDPOINT);
        const serviceName = requestURL.searchParams.get('serviceName');
        const subscriptionsOfAccount = SUBSCRIPTIONS.filter(subscription => subscription && subscription.serviceName === serviceName);
        return [200, { items: subscriptionsOfAccount || [] }];
    })

    // list subscriptions by account
    .get(escapeForwardSlash(`${SUBSCRIPTION_API_PREFIX}/.+`))
    .delay(100)
    .reply(function (uri) {
        const requestURL = new URL(uri, SUBSCRIPTION_ENDPOINT);
        const accountId = last(requestURL.pathname.split('/'));
        const userId = findUserId(this.req.headers['x-user-token']);
        if (!USERS[userId] && !userId.includes('clients')) {
            USERS[userId] = createScenarioForUser(userId);
        }
        if (USERS[userId] && USERS[userId].ACCOUNTS[accountId]) {
            const subscriptions = SUBSCRIPTIONS.filter(subscription => subscription.accounts && subscription.accounts.includes(accountId));
            return [200, subscriptions];
        }
        return [404, 'Account was not found'];
    });
subscriptionServiceScope.persist(true);
