const got = require('got');
const {
    AGENT_ENDPOINT, AGENT_API_PREFIX, AGENT_API_PROVIDERS_PREFIX, AGENT_LIST_AZURE_REGIONS
} = require('../../../src/utils/consts');
const { signJwtToken } = require('../simulator-utils');
require('../scopes/agent-azure-scope');

describe('azure-agent-scope', () => {
    test('Get regions', async () => {
        const url = `${AGENT_ENDPOINT}${AGENT_API_PREFIX}accountId${AGENT_API_PROVIDERS_PREFIX}${AGENT_LIST_AZURE_REGIONS}`;
        const data = await got.get(url, {
            resolveBodyOnly: true,
            responseType: 'json',
            headers: {
                'X-Agent-Id': 'agentId',
                authorization: signJwtToken()
            }
        });
        const expectedRegions = [{
            name: 'eastasia', displayName: 'East Asia', id: '/subscriptions/1b05f27b-7dd6-43eb-9164-e1903d7a4327/locations/eastasia', latitude: '22.267', longitude: '114.188'
        }, {
            name: 'southeastasia', displayName: 'Southeast Asia', id: '/subscriptions/1b05f27b-7dd6-43eb-9164-e1903d7a4327/locations/southeastasia', latitude: '1.283', longitude: '103.833'
        }, {
            name: 'centralus', displayName: 'Central US', id: '/subscriptions/1b05f27b-7dd6-43eb-9164-e1903d7a4327/locations/centralus', latitude: '41.5908', longitude: '-93.6208'
        }, {
            name: 'eastus', displayName: 'East US', id: '/subscriptions/1b05f27b-7dd6-43eb-9164-e1903d7a4327/locations/eastus', latitude: '37.3719', longitude: '-79.8164'
        }, {
            name: 'eastus2', displayName: 'East US 2', id: '/subscriptions/1b05f27b-7dd6-43eb-9164-e1903d7a4327/locations/eastus2', latitude: '36.6681', longitude: '-78.3889'
        }, {
            name: 'westus', displayName: 'West US', id: '/subscriptions/1b05f27b-7dd6-43eb-9164-e1903d7a4327/locations/westus', latitude: '37.783', longitude: '-122.417'
        }, {
            name: 'northcentralus', displayName: 'North Central US', id: '/subscriptions/1b05f27b-7dd6-43eb-9164-e1903d7a4327/locations/northcentralus', latitude: '41.8819', longitude: '-87.6278'
        }, {
            name: 'southcentralus', displayName: 'South Central US', id: '/subscriptions/1b05f27b-7dd6-43eb-9164-e1903d7a4327/locations/southcentralus', latitude: '29.4167', longitude: '-98.5'
        }, {
            name: 'northeurope', displayName: 'North Europe', id: '/subscriptions/1b05f27b-7dd6-43eb-9164-e1903d7a4327/locations/northeurope', latitude: '53.3478', longitude: '-6.2597'
        }, {
            name: 'westeurope', displayName: 'West Europe', id: '/subscriptions/1b05f27b-7dd6-43eb-9164-e1903d7a4327/locations/westeurope', latitude: '52.3667', longitude: '4.9'
        }, {
            name: 'japanwest', displayName: 'Japan West', id: '/subscriptions/1b05f27b-7dd6-43eb-9164-e1903d7a4327/locations/japanwest', latitude: '34.6939', longitude: '135.5022'
        }, {
            name: 'japaneast', displayName: 'Japan East', id: '/subscriptions/1b05f27b-7dd6-43eb-9164-e1903d7a4327/locations/japaneast', latitude: '35.68', longitude: '139.77'
        }, {
            name: 'brazilsouth', displayName: 'Brazil South', id: '/subscriptions/1b05f27b-7dd6-43eb-9164-e1903d7a4327/locations/brazilsouth', latitude: '-23.55', longitude: '-46.633'
        }, {
            name: 'australiaeast', displayName: 'Australia East', id: '/subscriptions/1b05f27b-7dd6-43eb-9164-e1903d7a4327/locations/australiaeast', latitude: '-33.86', longitude: '151.2094'
        }, {
            name: 'australiasoutheast', displayName: 'Australia Southeast', id: '/subscriptions/1b05f27b-7dd6-43eb-9164-e1903d7a4327/locations/australiasoutheast', latitude: '-37.8136', longitude: '144.9631'
        }, {
            name: 'southindia', displayName: 'South India', id: '/subscriptions/1b05f27b-7dd6-43eb-9164-e1903d7a4327/locations/southindia', latitude: '12.9822', longitude: '80.1636'
        }, {
            name: 'centralindia', displayName: 'Central India', id: '/subscriptions/1b05f27b-7dd6-43eb-9164-e1903d7a4327/locations/centralindia', latitude: '18.5822', longitude: '73.9197'
        }, {
            name: 'westindia', displayName: 'West India', id: '/subscriptions/1b05f27b-7dd6-43eb-9164-e1903d7a4327/locations/westindia', latitude: '19.088', longitude: '72.868'
        }, {
            name: 'canadacentral', displayName: 'Canada Central', id: '/subscriptions/1b05f27b-7dd6-43eb-9164-e1903d7a4327/locations/canadacentral', latitude: '43.653', longitude: '-79.383'
        }, {
            name: 'canadaeast', displayName: 'Canada East', id: '/subscriptions/1b05f27b-7dd6-43eb-9164-e1903d7a4327/locations/canadaeast', latitude: '46.817', longitude: '-71.217'
        }, {
            name: 'uksouth', displayName: 'UK South', id: '/subscriptions/1b05f27b-7dd6-43eb-9164-e1903d7a4327/locations/uksouth', latitude: '50.941', longitude: '-0.799'
        }, {
            name: 'ukwest', displayName: 'UK West', id: '/subscriptions/1b05f27b-7dd6-43eb-9164-e1903d7a4327/locations/ukwest', latitude: '53.427', longitude: '-3.084'
        }, {
            name: 'westcentralus', displayName: 'West Central US', id: '/subscriptions/1b05f27b-7dd6-43eb-9164-e1903d7a4327/locations/westcentralus', latitude: '40.890', longitude: '-110.234'
        }, {
            name: 'westus2', displayName: 'West US 2', id: '/subscriptions/1b05f27b-7dd6-43eb-9164-e1903d7a4327/locations/westus2', latitude: '47.233', longitude: '-119.852'
        }, {
            name: 'koreacentral', displayName: 'Korea Central', id: '/subscriptions/1b05f27b-7dd6-43eb-9164-e1903d7a4327/locations/koreacentral', latitude: '37.5665', longitude: '126.9780'
        }, {
            name: 'koreasouth', displayName: 'Korea South', id: '/subscriptions/1b05f27b-7dd6-43eb-9164-e1903d7a4327/locations/koreasouth', latitude: '35.1796', longitude: '129.0756'
        }, {
            name: 'francecentral', displayName: 'France Central', id: '/subscriptions/1b05f27b-7dd6-43eb-9164-e1903d7a4327/locations/francecentral', latitude: '46.3772', longitude: '2.3730'
        }, {
            name: 'francesouth', displayName: 'France South', id: '/subscriptions/1b05f27b-7dd6-43eb-9164-e1903d7a4327/locations/francesouth', latitude: '43.8345', longitude: '2.1972'
        }, {
            name: 'australiacentral', displayName: 'Australia Central', id: '/subscriptions/1b05f27b-7dd6-43eb-9164-e1903d7a4327/locations/australiacentral', latitude: '-35.3075', longitude: '149.1244'
        }, {
            name: 'australiacentral2', displayName: 'Australia Central 2', id: '/subscriptions/1b05f27b-7dd6-43eb-9164-e1903d7a4327/locations/australiacentral2', latitude: '-35.3075', longitude: '149.1244'
        }, {
            name: 'uaecentral', displayName: 'UAE Central', id: '/subscriptions/1b05f27b-7dd6-43eb-9164-e1903d7a4327/locations/uaecentral', latitude: '24.466667', longitude: '54.366669'
        }, {
            name: 'uaenorth', displayName: 'UAE North', id: '/subscriptions/1b05f27b-7dd6-43eb-9164-e1903d7a4327/locations/uaenorth', latitude: '25.266666', longitude: '55.316666'
        }, {
            name: 'southafricanorth', displayName: 'South Africa North', id: '/subscriptions/1b05f27b-7dd6-43eb-9164-e1903d7a4327/locations/southafricanorth', latitude: '-25.731340', longitude: '28.218370'
        }, {
            name: 'southafricawest', displayName: 'South Africa West', id: '/subscriptions/1b05f27b-7dd6-43eb-9164-e1903d7a4327/locations/southafricawest', latitude: '-34.075691', longitude: '18.843266'
        }, {
            name: 'switzerlandnorth', displayName: 'Switzerland North', id: '/subscriptions/1b05f27b-7dd6-43eb-9164-e1903d7a4327/locations/switzerlandnorth', latitude: '47.451542', longitude: '8.564572'
        }, {
            name: 'switzerlandwest', displayName: 'Switzerland West', id: '/subscriptions/1b05f27b-7dd6-43eb-9164-e1903d7a4327/locations/switzerlandwest', latitude: '46.204391', longitude: '6.143158'
        }, {
            name: 'germanynorth', displayName: 'Germany North', id: '/subscriptions/1b05f27b-7dd6-43eb-9164-e1903d7a4327/locations/germanynorth', latitude: '53.073635', longitude: '8.806422'
        }, {
            name: 'germanywestcentral', displayName: 'Germany West Central', id: '/subscriptions/1b05f27b-7dd6-43eb-9164-e1903d7a4327/locations/germanywestcentral', latitude: '50.110924', longitude: '8.682127'
        }, {
            name: 'norwaywest', displayName: 'Norway West', id: '/subscriptions/1b05f27b-7dd6-43eb-9164-e1903d7a4327/locations/norwaywest', latitude: '58.969975', longitude: '5.733107'
        }, {
            name: 'norwayeast', displayName: 'Norway East', id: '/subscriptions/1b05f27b-7dd6-43eb-9164-e1903d7a4327/locations/norwayeast', latitude: '59.913868', longitude: '10.752245'
        }];
        expect(data).toEqual(expectedRegions);
    });
});
