const got = require('got');
const {
    AGENT_SGWS_PATH,
    AGENT_LIST_SGWS_BUCKETS, AGENT_CREATE_SGWS_BUCKET,
    AGENT_ENDPOINT, AGENT_API_PREFIX, AGENT_API_PROVIDERS_PREFIX
} = require('../../../src/utils/consts');
const { signJwtToken } = require('../simulator-utils');
require('../scopes/agent-sgws-scope');

describe('sgws-agent-scope', () => {
    test('Create bucket and receive it back on get buckets', async () => {
        const name = 'test';
        const host = '1.1.1.1';
        const port = 80;
        const bucket = {
            name,
            host,
            port
        };
        // create bucket
        await got.post(`${AGENT_ENDPOINT}${AGENT_API_PREFIX}accountId${AGENT_API_PROVIDERS_PREFIX}${AGENT_CREATE_SGWS_BUCKET}`, {
            resolveBodyOnly: true,
            responseType: 'json',
            json: bucket,
            headers: {
                'X-Agent-Id': 'agentId',
                authorization: signJwtToken(),
                accessKey: 'a',
                secretKey: 's'
            }
        });

        const buckets = await got.get(`${AGENT_ENDPOINT}${AGENT_API_PREFIX}accountId/${AGENT_API_PROVIDERS_PREFIX}${AGENT_LIST_SGWS_BUCKETS}?host=${host}&port=${port}`, {
            resolveBodyOnly: true,
            responseType: 'json',
            headers: {
                'X-Agent-Id': 'agentId',
                authorization: signJwtToken(),
                accessKey: 'a',
                secretKey: 'b'
            }
        });

        // get bucket
        const foundBucket = buckets.find(bucketObj => bucketObj.name === name);
        expect(foundBucket.name).toBe(name);
    });

    test('Create bucket, try to create the same bucket and fail', async () => {
        const name = 'test22';
        const host = '1.1.1.1';
        const port = 80;
        const bucket = {
            name,
            host,
            port
        }; // create bucket
        await got.post(`${AGENT_ENDPOINT}${AGENT_API_PREFIX}accountId${AGENT_API_PROVIDERS_PREFIX}${AGENT_CREATE_SGWS_BUCKET}`, {
            resolveBodyOnly: true,
            responseType: 'json',
            json: bucket,
            headers: {
                'X-Agent-Id': 'agentId',
                authorization: signJwtToken(),
                accessKey: 'a',
                secretKey: 's'
            }
        });

        try {
            await got.post(`${AGENT_ENDPOINT}${AGENT_API_PREFIX}accountId${AGENT_API_PROVIDERS_PREFIX}${AGENT_CREATE_SGWS_BUCKET}`, {
                resolveBodyOnly: true,
                responseType: 'json',
                json: bucket,
                headers: {
                    'X-Agent-Id': 'agentId',
                    authorization: signJwtToken(),
                    accessKey: 'a',
                    secretKey: 's'
                }
            });
        } catch (err) {
            expect(err.response.body.message).toEqual(`A bucket with name ${bucket.name} already exist. please try again`);
        }
    });

    test('try to put object with accessKey failToPut, should fail', async () => {
        const name = 'test4';
        const host = '1.1.1.1';
        const port = 80;
        const accessKey = 'failedToPut';
        const secretKey = 'b';
        const bucket = {
            name, host, port
        };
        // create bucket
        await got.post(`${AGENT_ENDPOINT}${AGENT_API_PREFIX}accountId${AGENT_API_PROVIDERS_PREFIX}${AGENT_CREATE_SGWS_BUCKET}`, {
            resolveBodyOnly: true,
            responseType: 'json',
            json: bucket,
            headers: {
                'X-Agent-Id': 'agentId',
                authorization: signJwtToken(),
                accessKey: 'a',
                secretKey: 's'
            }
        });

        try {
            await got.put(`${AGENT_ENDPOINT}${AGENT_API_PREFIX}accountId${AGENT_API_PROVIDERS_PREFIX}${AGENT_SGWS_PATH}/${name}/test`, {
                resolveBodyOnly: true,
                responseType: 'json',
                json: {
                    accessKey, secretKey, host, port, bucket: name, body: '1'
                },
                headers: {
                    'X-Agent-Id': 'agentId',
                    authorization: signJwtToken(),
                    accessKey: 'a',
                    secretKey: 's'
                }
            });
        } catch (err) {
            expect(err.response.body.statusCode).toBe(403);
        }
    });

    test('try to put object with accessKey failToGet, should fail', async () => {
        const name = 'test5';
        const host = '1.1.1.1';
        const port = 80;
        const accessKey = 'failToGet';
        const secretKey = 'b';
        const bucket = {
            name, host, port
        };
        // create bucket
        await got.post(`${AGENT_ENDPOINT}${AGENT_API_PREFIX}accountId${AGENT_API_PROVIDERS_PREFIX}${AGENT_CREATE_SGWS_BUCKET}`, {
            resolveBodyOnly: true,
            responseType: 'json',
            json: bucket,
            headers: {
                'X-Agent-Id': 'agentId',
                authorization: signJwtToken(),
                accessKey: 'a',
                secretKey: 's'
            }
        });

        try {
            await got.get(`${AGENT_ENDPOINT}${AGENT_API_PREFIX}accountId${AGENT_API_PROVIDERS_PREFIX}${AGENT_SGWS_PATH}/${name}/test?host=${host}&port=${port}`, {
                resolveBodyOnly: true,
                responseType: 'json',
                headers: {
                    'X-Agent-Id': 'agentId',
                    authorization: signJwtToken(),
                    accessKey,
                    secretKey
                }
            });
        } catch (err) {
            expect(err.response.body.statusCode).toBe(403);
        }
    });

    test('try to put object with accessKey failToDelete, should fail', async () => {
        const name = 'test6';
        const host = '1.1.1.1';
        const port = 80;
        const accessKey = 'failToDelete';
        const secretKey = 'b';
        const bucket = {
            name, host, port
        };
        // create bucket
        await got.post(`${AGENT_ENDPOINT}${AGENT_API_PREFIX}accountId${AGENT_API_PROVIDERS_PREFIX}${AGENT_CREATE_SGWS_BUCKET}`, {
            resolveBodyOnly: true,
            responseType: 'json',
            json: bucket,
            headers: {
                'X-Agent-Id': 'agentId',
                authorization: signJwtToken(),
                accessKey: 'a',
                secretKey: 's'
            }
        });

        try {
            await got.delete(`${AGENT_ENDPOINT}${AGENT_API_PREFIX}accountId${AGENT_API_PROVIDERS_PREFIX}${AGENT_SGWS_PATH}/${name}/test?host=${host}&port=${port}`, {
                resolveBodyOnly: true,
                responseType: 'json',
                headers: {
                    'X-Agent-Id': 'agentId',
                    authorization: signJwtToken(),
                    accessKey,
                    secretKey
                }
            });
        } catch (err) {
            expect(err.response.body.statusCode).toBe(403);
        }
    });
});
