const {
    AWS, AZURE, GCP, UNKNOWN_STATUS, FAILED_STATUS, ON_STATUS, AGENT_ACTIVE_STATUS
} = require('../src/utils/consts');

function createAccount(accountId, freeTrialExpiryDate) {
    return { accountId, freeTrialExpiryDate, support: { serialNumber: '111' } };
}

function createCluster(accountId, clusterId, clusterUuid, cloudProvider, subscriptionId, tieringLicense, byolLicense, currentCapacity, lastSeen, isEligibleForTieirng, agentId) {
    return {
        accountId, clusterId, clusterUuid, cloudProvider, subscriptionId, tieringLicense, byolLicense, currentCapacity, lastSeen, isEligibleForTieirng, agentId
    };
}

function createSubscription(accountId, status, cloudProvider, subscriptionId, serviceName) {
    return {
        accountId, status, cloudProvider, subscriptionId, serviceName
    };
}

function createAgent(name, status, agentId, containerStatus = AGENT_ACTIVE_STATUS) {
    return {
        name,
        provider: 'aws',
        region: 'us-east-1',
        network: 'vpc-5b46c03e',
        subnet: 'subnet-f1f526a8',
        status,
        useDockerInfra: true,
        systemId: 'systemId',
        agentId,
        clientInfraStatus: {
            cloudmanager_tiering: {
                version: 'cloudmanagerinfra.azurecr.io/cloudmanager_tiering:development-84fb9c7-267',
                status: containerStatus,
                reason: 'System is up and running'
            }
        }
    };
}

function createObjectStoreConfigExtended(withTiering, ontapVersion, cloudProvider = AWS, usedSpace) {
    if (ontapVersion >= 9.2 && withTiering) {
        let providerType;
        let tierLevel;
        let server;
        if (cloudProvider === AWS) {
            providerType = 'aws_s3';
            server = 's3-us-west-2.amazonaws.com';
            tierLevel = 'normal';
        } else if (cloudProvider === AZURE) {
            server = 'cksyondgw93usuh.blob.core.windows.net';
            providerType = 'azure_cloud';
            tierLevel = 'normal';
        } else if (cloudProvider === GCP) {
            providerType = 'googlecloud';
            server = 'storage.googleapis.com';
            tierLevel = 'standard';
        }
        return {
            objectStoreConfig: {
                objectStoreName: 'StorageAccount',
                s3Name: 'fabric-pool-e2f48c0c-b214-11e9-9fc8-000d3a556f77',
                usedSpace,
                server,
                providerType
            },
            tierLevel
        };
    }
    return { objectStoreConfig: null, tierLevel: null };
}

function createClusterInfoResponse(publicId, status, clusterUuid = '8477dc48-5a84-11e7-a7dc-00a098b0e4d0', withTiering = true, tieringCloudProvider = AWS, tieredUsedSpace = 920243508, ontapVersion = '9.6') {
    switch (status) {
        case FAILED_STATUS: {
            return {
                publicId,
                name: 'failed',
                status: {
                    status: FAILED_STATUS,
                    message: 'Invalid ONTAP credentials'
                },
                replicationProperties: null,
                clusterProperties: null,
                ontapClusterProperties: {
                    clusterAddress: '1.1.1.1',
                    ontapVersion: '',
                    clusterName: '',
                    serialNumber: '',
                    systemId: '',
                    isSnapmirrorLicenseExists: false,
                    licenses: [],
                    systemManagerUrl: 'https://1.1.1.1/sysmgr/SysMgr.html',
                    location: {
                        enumClass: 'com.netapp.oncloud.rest.onprem.OnPremWorkingEnvironmentLocation',
                        value: 'ON_PREM'
                    },
                    clusterUuid: 'Trading-uuid',
                    nodeModels: [],
                    lifs: []
                },
                workingEnvironmentType: 'ON_PREM',
                cloudSyncProperties: null,
                actionsRequired: null,
                capacityFeatures: {
                    objectStoreConfigExtended: null,
                    performanceTierUsedCapacity: 0,
                    inactiveUserData: null,
                    rawCapacity: 0,
                    fiveYearSavings: 0
                },
                aff: false,
                k8sProperties: null
            };
        }
        case UNKNOWN_STATUS: {
            return {
                publicId,
                name: undefined,
                status: { status: UNKNOWN_STATUS, message: 'ECONNABORTED' }
            };
        }
        case ON_STATUS: {
            const objectStoreConfigExtended = createObjectStoreConfigExtended(withTiering, ontapVersion, tieringCloudProvider, tieredUsedSpace);
            return {
                publicId,
                tenantId: 'Tenant-ODqPQ7O4',
                description: '',
                name: 'BRARUPP-NetApCLU',
                discoverUserEmail: 'auth0',
                location: 'ON_PREM',
                reservedSize: null,
                status: {
                    status: ON_STATUS,
                    failureCauses: {
                        invalidOntapCredentials: false,
                        noCloudProviderConnection: false,
                        invalidCloudProviderCredentials: false
                    },
                    extendedFailureReason: null
                },
                interClusterLifs: null,
                cronJobSchedules: null,
                svms: null,
                snapshotPolicies: null,
                replicationProperties: null,
                clusterProperties: null,
                ontapClusterProperties: {
                    clusterAddress: '163.34.231.48',
                    ontapVersion,
                    clusterName: 'BRARUPP-NetApCLU',
                    serialNumber: '621714000169',
                    systemId: '0537086728',
                    isSnapmirrorLicenseExists: true,
                    licenses: ['snapmirror', 'snapvault'],
                    systemManagerUrl: 'https://163.34.231.48/sysmgr/SysMgr.html',
                    location: {
                        enumClass: 'com.netapp.oncloud.rest.onprem.OnPremWorkingEnvironmentLocation',
                        value: 'ON_PREM'
                    },
                    clusterUuid,
                    nodeModels: ['FAS2650', 'FAS2650'],
                    lifs: [{
                        name: 'BRARUPP-NetApCLU-01_mgmt1',
                        status: 'up',
                        role: 'node_mgmt',
                        ipSpace: 'Default'
                    }]
                },
                workingEnvironmentType: 'ON_PREM',
                cloudSyncProperties: null,
                actionsRequired: null,
                capacityFeatures: {
                    objectStoreConfigExtended
                },
                aff: false
            };
        }
        default: {
            throw new Error('Unknown status');
        }
    }
}

function createLicenseStatusResponse(byol = false, maxCapacity = 2199023255552) {
    return {
        currentCapacity: 500, // GB
        maxCapacity,
        serialNumber: byol ? '360000099' : '22654892',
        package: 'fabricpool'
    };
}

function createAggregate(name, state = 'online', isRoot = false, isComposite = true, isInactiveDataReportingEnabled = true, isObjectStoreAttachEligible = true, totalCapacity = 5497558138880, usedCapacity = 2199023255552) {
    return {
        name,
        state,
        isRoot,
        isComposite,
        isInactiveDataReportingEnabled,
        isObjectStoreAttachEligible,
        totalCapacity,
        usedCapacity
    };
}

function createClusterRequest(publicId, status, clusterUuid = '8477dc48-5a84-11e7-a7dc-00a098b0e4d0', ontapVersion = '9.6') {
    switch (status) {
        case FAILED_STATUS: {
            return {
                publicId,
                name: 'failed',
                status: {
                    status: FAILED_STATUS,
                    message: 'Invalid ONTAP credentials'
                },
                replicationProperties: null,
                clusterProperties: null,
                ontapClusterProperties: {
                    clusterAddress: '1.1.1.1',
                    ontapVersion: '',
                    clusterName: '',
                    serialNumber: '',
                    systemId: '',
                    isSnapmirrorLicenseExists: false,
                    licenses: [],
                    systemManagerUrl: 'https://1.1.1.1/sysmgr/SysMgr.html',
                    location: {
                        enumClass: 'com.netapp.oncloud.rest.onprem.OnPremWorkingEnvironmentLocation',
                        value: 'ON_PREM'
                    },
                    clusterUuid: 'Trading-uuid',
                    nodeModels: [],
                    lifs: []
                },
                workingEnvironmentType: 'ON_PREM',
                cloudSyncProperties: null,
                actionsRequired: null,
                capacityFeatures: {
                    objectStoreConfigExtended: null,
                    performanceTierUsedCapacity: 0,
                    inactiveUserData: null,
                    rawCapacity: 0,
                    fiveYearSavings: 0
                },
                aff: false,
                k8sProperties: null
            };
        }
        case UNKNOWN_STATUS: {
            return {
                publicId,
                name: undefined,
                status: { status: UNKNOWN_STATUS, message: 'ECONNABORTED' }
            };
        }
        case ON_STATUS: {
            return {
                publicId,
                tenantId: 'Tenant-ODqPQ7O4',
                description: '',
                name: 'BRARUPP-NetApCLU',
                discoverUserEmail: 'auth0',
                location: 'ON_PREM',
                reservedSize: null,
                status: {
                    status: ON_STATUS,
                    failureCauses: {
                        invalidOntapCredentials: false,
                        noCloudProviderConnection: false,
                        invalidCloudProviderCredentials: false
                    },
                    extendedFailureReason: null
                },
                interClusterLifs: null,
                cronJobSchedules: null,
                svms: null,
                snapshotPolicies: null,
                replicationProperties: null,
                clusterProperties: null,
                ontapClusterProperties: {
                    clusterAddress: '163.34.231.48',
                    ontapVersion,
                    clusterName: 'BRARUPP-NetApCLU',
                    serialNumber: '621714000169',
                    systemId: '0537086728',
                    isSnapmirrorLicenseExists: true,
                    licenses: ['snapmirror', 'snapvault'],
                    systemManagerUrl: 'https://163.34.231.48/sysmgr/SysMgr.html',
                    location: {
                        enumClass: 'com.netapp.oncloud.rest.onprem.OnPremWorkingEnvironmentLocation',
                        value: 'ON_PREM'
                    },
                    clusterUuid,
                    nodeModels: ['FAS2650', 'FAS2650'],
                    lifs: [{
                        name: 'BRARUPP-NetApCLU-01_mgmt1',
                        status: 'up',
                        role: 'node_mgmt',
                        ipSpace: 'Default'
                    }]
                },
                workingEnvironmentType: 'ON_PREM',
                cloudSyncProperties: null,
                actionsRequired: null,
                capacityFeatures: {
                    objectStoreConfigExtended: null
                },
                aff: false
            };
        }
        default: {
            throw new Error('Unknown status');
        }
    }
}
module.exports = {
    createAggregate,
    createClusterRequest,
    createLicenseStatusResponse,
    createClusterInfoResponse,
    createSubscription,
    createAccount,
    createCluster,
    createAgent
};
