import React, {useEffect} from 'react';
import {connect} from 'react-redux';
import {buildUrlParams} from '../utils/encoders';
import mapDispatchToProps from '../dispatchers/routingInfoDispatcher';
import {withRouter} from 'react-router-dom';

import './contentWrapper.scss';
import ToasterNotification from "./widgets/ToasterNotification";

const ContentWrapper = (props) => {
    const {
        content: Content,
        headerComponent: HeaderComponent,
        bodyClass,
        routingInfo,
        updateUrlParams,
        match,
        location,
        hideGlobalNotifications = false
    } = props;

    useEffect(() => {
        if (routingInfo.href && routingInfo.href !== window.location.href) {
            updateUrlParams(buildUrlParams(match, location, window.location.href));
        }
    }, [routingInfo, updateUrlParams, match, location])


    return (
        <div className={`content-wrapper ${bodyClass}`}>
            {HeaderComponent && <HeaderComponent {...props} />}
            <Content {...props}/>
            {!hideGlobalNotifications && <ToasterNotification />}
        </div>
    )
}

const mapStateToProps = state => {
    return {
        wizard: state.wizardReducer.wizard,
        routing: state.router,
        routingInfo: state.appRouting.routingInfo
    };
};


export default withRouter(connect(mapStateToProps, mapDispatchToProps)(ContentWrapper));


