import React, {useState, useMemo, useCallback} from 'react';
import {calculateNextStep, getNextStepComponent} from '../wizard/WizardStarter';
import {Route, Switch} from 'react-router';
import {Field, formValueSelector, reduxForm} from 'redux-form';
import mapStateToProps from '../wizard/wizardMapStateToProps';
import {connect} from 'react-redux';
import stepinize from '../wizard/stepinize';
import classNames from 'classnames';
import SetupWizardDiagram from './SetupWizardDiagram';
import ButtonsPanelWithError from '../widgets/ButtonsPanelWithError';
import {CHANGE_TIER_LEVEL_G} from '../../graphql/queries';
import {DEFAULT_STORAGE_CLASS, PROVIDER_TYPE_AZURE, STORAGE_CLASSES, TIERING_SETUP_TITLES} from '../../utils/consts';
import _ from 'lodash';
import { extractError, sendMixPanelEvent } from '../../utils/utils';
import { ControlledSelectField} from '../forms/forms';
import InternalWizardHeader from '../wizard/InternalWizardHeader';
import Button from "../widgets/Button";
import useRunOnceWhenTruthy from '../../hooks/useRunOnceWhenTruthy'
import { useMutation } from '@apollo/client'

require('./setupStorageClassStepAzure.scss');

const handleError = (error, action, setError) => {
    const errorMessage = extractError(error, 'Storage Class Step');
    sendMixPanelEvent(action, 'SetupStorageClassAzure')
    setError(errorMessage)
}


const SetupStorageClassStepAzure = (props) => {
    const {wizard, history, change, handleSubmit, accountId, agentId, storageClassFromForm} = props
    const storageAccount = _.get(wizard.selectedWizardParams, 'storageAccount', null);
    const resourceGroup = _.get(wizard.selectedWizardParams, 'resourceGroup', null);
    const provider = _.get(wizard.selectedWizardParams, 'provider', null);
    const [error, setError] = useState(null)

    const nextStep = () => {
        const nextStep = calculateNextStep(wizard);
        wizard.nextStep(`/${storageClassFromForm.value}/${nextStep}`, history);
    }


    const [changeTierLevelMuation, {loading: loadingConfigureBucket}] = useMutation(CHANGE_TIER_LEVEL_G, {
        onCompleted: nextStep,
        onError: (error) => handleError(error, 'changeTierLevelAzure', setError),
        errorPolicy: 'all'

    })

    const storageClassOptions = useMemo(() =>_.map(STORAGE_CLASSES[provider], storageClass => {
        return {
            label: storageClass.storageClassName,
            value: storageClass.storageClass
        };
    }), [provider]);

    useRunOnceWhenTruthy(() => {
        const storageClass = provider ? _.get(wizard.selectedWizardParams, ['storageClass'], STORAGE_CLASSES[provider][DEFAULT_STORAGE_CLASS].storageClass) : null;
        if (storageClass) {
            const selectedStorageClass = _.find(storageClassOptions, {value: storageClass}) || '';
            change('storageClass', selectedStorageClass)
        }

    }, storageClassOptions)


    const changeTierLevel = useCallback((values) =>{
        const { storageClass} = values
        return changeTierLevelMuation({
            variables: {
                cloudProvider: PROVIDER_TYPE_AZURE.name,
                [PROVIDER_TYPE_AZURE.name.toLowerCase()]: {
                    accountId,
                    agentId,
                    storageAccount,
                    resourceGroup,
                    level: storageClass.value
                }
            }
        });
    }, [accountId, agentId, resourceGroup, storageAccount, changeTierLevelMuation])

    const getContentUX = (provider) => {
        return (
            <div className="pane center">
                <div className="storage-class-container">
                    <label>Access Tier</label>
                    <Field component={ControlledSelectField}
                           name="storageClass"
                           options={storageClassOptions}
                           className="storage-class" ></Field>
                </div>
            </div>

        );
    }

    if (!provider) {
        return <div></div>;
    }

    return (
        <div className={classNames('setup-storage-class-step new-wizard-step')}>
            <div className="panels-container">
                <div className="left-panel">
                    <div className="pane center">
                        <h1>Tiering Setup</h1>
                        <InternalWizardHeader {...props}/>
                        {TIERING_SETUP_TITLES[provider].title2}
                    </div>
                    <form
                        onSubmit={handleSubmit(changeTierLevel)}>
                        <div>
                            <div className="step-content">
                                {getContentUX(provider)}
                            </div>
                            <div className="wizard-button">
                                <div className="wizard-button">
                                    <ButtonsPanelWithError error={error}
                                                           submitting={loadingConfigureBucket}>
                                        <Button type="submit"
                                                disabled={loadingConfigureBucket}>Continue</Button>
                                    </ButtonsPanelWithError>
                                </div>
                            </div>
                        </div>
                    </form>
                </div>
                <SetupWizardDiagram flowStep="cluster-discovered"/>
            </div>
        </div>
    );
}

const nextRoutes = ({match, wizard}) => {
    const nextStep = calculateNextStep(wizard, 'Setup Storage Class Azure');
    const NextStepComp = getNextStepComponent(nextStep);
    return (
        <Switch>
            <Route path={`${match.url}/:storageClass/${nextStep}`} render={(props) => <NextStepComp {...props}/>}/>
        </Switch>
    );
};

let StorageClassStepForm = reduxForm({
    form: 'setupStorageClassAzureForm'
})(SetupStorageClassStepAzure);

const selector = formValueSelector('setupStorageClassAzureForm');
const combineStateObjects = (state, ownProps) => {
    const storageClass = selector(state, 'storageClass');
    return Object.assign({}, mapStateToProps(state, ownProps), {
        storageClassFromForm: storageClass
    });
};
export default connect(combineStateObjects)(stepinize(StorageClassStepForm, {
    name: () => `Setup Storage Class Azure`,
    nextRoutes
}));

