import React, {useState} from 'react';
import {useMutation} from '@apollo/client';
import {REMOVE_CLUSTER} from '../../graphql/queries';
import {NOTIFICATION_TYPES} from '../../utils/consts';
import DefaultDialogLayout from '../widgets/DefaultDialogLayout';
import {removeClusterFromCache} from "../../utils/cacheUtil";
import {connect} from "react-redux";

require('./removeClusterDialog.scss');

const RemoveClusterDialog = ({closeDialog, clusterId, addNotification, agentId, accountId, workspaceId}) => {
    const [removeCluster, {loading}] = useMutation(REMOVE_CLUSTER,
        {
            update: (proxy) => removeClusterFromCache(proxy, clusterId, agentId, accountId, workspaceId)
        }
    );

    const [showError, setShowError] = useState(null);
    return (
        <DefaultDialogLayout
            styleClass='remove-cluster-dialog'
            title={'Remove Cluster'}
            buttonsArr={[
                {
                    text: 'Remove',
                    styleClass: 'new-wizard',
                    loading,
                    onClick: () => {
                        setShowError(null);
                        removeCluster({
                            variables: {clusterId, accountId, agentId, workspaceId},
                        })
                            .then(() => {
                                addNotification({
                                    variant: NOTIFICATION_TYPES.SUCCESS,
                                    text: 'Cluster has been removed successfully'
                                })
                                closeDialog();
                            })
                            .catch((error) => {
                                console.log(`%c Error removing cluster ${clusterId} error: ${JSON.stringify(error, undefined, 2)}`, 'font-weight:bold; color:red');
                                setShowError(error.message);
                            });
                    }
                },
                {
                    text: 'Cancel',
                    styleClass: 'secondary',
                    disabled: loading,
                    onClick: closeDialog
                }
            ]}
            errorMessage={showError}>
            <div className="first-paragraph">Are you sure that you want to remove this cluster?</div>
            <div className="second-paragraph">This action removes the cluster from Cloud Tiering (not from Cloud
                Manager). If configured, the cluster
                will continue to tier data to the cloud. Pay-as-you-go charging will also continue, if you set it up.
                You can rediscover the cluster at any time.
            </div>
        </DefaultDialogLayout>
    );
};

const mapStateToProps = state => ({
    agentId: state.general.agentId,
    accountId: state.general.accountId,
    workspaceId: state.general.workspaceId,
});

export default connect(mapStateToProps)(RemoveClusterDialog);
