import React from 'react';
import {openDialog} from "../../dialog/Dialog"
import { FREE_TRIAL_EXPIRED, FREE_TRIAL_PERIOD, PAYGO, SUBSCRIBED } from './../../../utils/consts';
import SubscriptionFlowDialog from "./SubscriptionFlowDialog";
import Isvg from 'react-inlinesvg';
import Button from "../../widgets/Button";

require("./subscribe.scss");

const SubscriptionContent = ({data: {subscribed, freeTrialStatus}}) => {
    const freeTrialExpired = freeTrialStatus === FREE_TRIAL_EXPIRED;
    const renderSubscribeTitle = () => {

        if (subscribed) {
            return (
                <div className="icon-with-title">
                    <Isvg  src={require("../../../assets/svgs/checkmark-circle-icon.svg")}/>
                    <span>Active Subscription - AWS Marketplace {PAYGO}</span>
                </div>
            );
        }

        else {
            return <span>Subscribe from the AWS Marketplace</span>
        }
    };

    const renderSubscribeText = () => {
        // build text dynamically
        let subscribeText;
        if (subscribed && !freeTrialExpired) {
            subscribeText = `After the ${FREE_TRIAL_PERIOD}-day free trial is over, you'll be charged hourly according to the amount of data that you tier.`;
        }

        else if (subscribed && freeTrialExpired) {
            subscribeText = `You will be charged hourly according to the amount of data you tier.`;
        }

        else if (!subscribed && !freeTrialExpired) {
            subscribeText = `Subscribe to the Cloud Tiering service to ensure that there's no disruption of service after your free trial ends.
            When the trial ends, you'll be charged hourly according to the amount of data that you tier.`
        }

        else if (!subscribed && freeTrialExpired) {
            subscribeText = `Your free trial has ended. While you can still read any existing data that you tiered, 
            you can't tier any further data until you subscribe from the AWS Marketplace. After subscribing you'll be charged hourly according to the amount of data that you tier.`
        }

        // only show price model link when subscribed (otherwise pricing model is shown on subscribe page itself)
        if (subscribed ||(!subscribed && freeTrialExpired)) {
            return (
                <span>
                    {subscribeText}
                    <a href="https://aws.amazon.com/marketplace/pp/B07QV3N5LM" target="_blank" rel="noopener noreferrer" > View the pricing model</a>
                </span>
            );
        }


        return <span>{subscribeText}</span>;
    };



    return (
      <div className="subscription-content">
          <div className="subscription-content-title">{renderSubscribeTitle()}</div>
          <div className="subscription-content-info">{renderSubscribeText()}</div>
      </div>
  )
};

export default ({licenseInfoStatus: {freeTrialStatus, subscriptionStatus}}) => {
    const subscribed = subscriptionStatus === SUBSCRIBED;

    return (
        <div className="subscription">
            <div><Isvg  src={require('../../../assets/svgs/marketplace.svg')}/></div>
            <SubscriptionContent data={{subscribed, freeTrialStatus}}/>
            <div className={`subscription-action ${subscriptionStatus}`}>
                {!subscribed && <Button onClick={(clickElement) => openDialog(<SubscriptionFlowDialog
                    className="confirm subscription-flow-dialog"/>, clickElement.target)}>Subscribe</Button>}
            </div>
        </div>
    )
};
