import React, { useState} from 'react';
import Isvg from 'react-inlinesvg';
import { buildCapacityObject } from '../../utils/utils';
import numeral from 'numeral';
import classNames from 'classnames';
import { DASHBOARD_TITLES } from '../../utils/consts';
import DefaultDialogLayout from '../widgets/DefaultDialogLayout';

require('./tieringPolicyDialog.scss');

const PolicyRow = ({
                       name, displayName, description, notSupportedVersionIcon, isEstimated, icon, setOpenState, open, total, count,
                       savingOpportunity: { cost, capacity }, details, supported: { isSupported, reason }, mostPopular
                   }) => {
    const freeUp = buildCapacityObject(capacity);
    const save = numeral(cost)
        .format('0a');
    const disabled = !isSupported;

    return (
        <div title={reason} className={classNames(`${name} policy-card`, { disabled })}>
            <div className="policy-row" onClick={() => setOpenState(name)}>
                <div className="left-part box">
                    <h3><Isvg className={classNames('policy-icon', name)} src={require(`./../../assets/svgs/${icon}`)}/>{description}</h3>
                    <h5>{`(${displayName} ${mostPopular ? ' - Most Popular' : ''}`}{mostPopular && <span className="popular-icon"><Isvg src={require('./../../assets/svgs/stars.svg')}/></span>}<span className={classNames('left-bracket', { 'most-popular': mostPopular })}>)</span></h5>
                    <div className="volumes">{count > 0 ? `${count}/${total} Available volumes` : 'No Available Volumes'}</div>
                    {!isSupported && notSupportedVersionIcon && <Isvg className="version-icon" src={require('./../../assets/svgs/ontap-v9-4-narrow-icon.svg')}/>}
                </div>
                <div className="vertical"></div>
                <div className="save box">
                    <div className="box-title">Save up to:</div>
                    <div className="box-value">{save}<span><Isvg src={require('./../../assets/svgs/save-icon.svg')}/></span></div>
                </div>
                <div className="vertical"/>
                <div className="free-up box">
                    <div className="box-title">Free up to:</div>
                    <div className="box-value">{freeUp.value}<span>{freeUp.unit}</span></div>
                </div>
                {!open &&
                <button onClick={() => setOpenState(name)}><Isvg
                    src={require('../../assets/svgs/triangle-down.svg')}/></button>}
                {open &&
                <button onClick={() => setOpenState(name)}><Isvg
                    src={require('../../assets/svgs/triangle-up.svg')}/></button>}
            </div>
            {open && <>
                <div className="policy-details">{details}</div>
                {isEstimated && <div className="policy-details">{DASHBOARD_TITLES.estimated}</div>}
            </>}
        </div>);
};

const TieringPolicyDialog = (props) => {
    const { policies, totalVolumes, closeDialog } = props;
    const [openPolicy, setOpenPolicy] = useState(null)

    const setOpenState = (policyName) => {
        setOpenPolicy(openPolicy === policyName ? null : policyName)
    }

    return (
        <DefaultDialogLayout
            styleClass='tiering-policy-dialog'
            title={'Tiering Policy Info'}
            buttonsArr={[{
                text: 'Close',
                styleClass: 'cancel-new-wizard',
                onClick: closeDialog
            }]}>
            {policies.map((policy) => {
                return (
                    <PolicyRow key={policy.name} {...policy} total={totalVolumes} open={openPolicy === policy.name} setOpenState={setOpenState}/>
                );
            })}
        </DefaultDialogLayout>
    );
}

export default TieringPolicyDialog

