import React, {Component} from 'react'
import {Field} from 'redux-form';
import {InputField} from "../forms/forms";
import classNames from 'classnames';
import _ from 'lodash'

require("./filterWidget.scss");

export default class FilterWidget extends Component {
    constructor(props, context) {
        super(props, context);
        const {filterValues} = this.props;
        const all = this.calculateAllFilter(filterValues);
        const clonedFilterValues = _.cloneDeep(filterValues);
        const filterList = [...clonedFilterValues];
        const originalFilterList = _.cloneDeep(filterList);
        this.state = {all, filterList, originalFilterList};
    }

    calculateAllFilter(filterValues) {
        const all = {
            className: "all",
            name: "all",
            value: "all",
            text: "All",
            count: _.reduce(filterValues, (total, value) => total + value.count, 0),
            checked: _.reduce(filterValues, (checked, value) => checked && value.checked, true)
        };
        return all;
    }

    componentDidMount() {
        document.addEventListener('mousedown', this.handleClickOutside.bind(this));
    }

    componentWillUnmount() {
        document.removeEventListener('mousedown', this.handleClickOutside.bind(this));
    }

    setWrapperRef(node) {
        this.wrapperRef = node;
    }

    handleClickOutside(event) {
        if (this.wrapperRef && !this.wrapperRef.contains(event.target)) {
            this.setState({filterList: _.cloneDeep(this.state.originalFilterList), all: this.calculateAllFilter(this.state.originalFilterList)}); //return to original list
            this.props.close();
        }
    }



    apply() {
        const { apply } = this.props;
        apply(this.state.filterList);
    }

    handleClick(name, event) {
        const filterList = this.state.filterList.map(filter => {
            if (name === "all"|| filter.name === name) {
                filter.checked = event.target.checked;
            }
            return filter;
        });
        const allFilter = this.state.all;
        allFilter.checked = _.reduce(filterList, (checked, value) => checked && value.checked, true);
        this.setState({all: allFilter, filterList})
    }

    render() {
        const {all, filterList} = this.state;
        const {fixed} = this.props;
        const buildFieldElement = (value) => {
            const valueText = `${value.text}  (${value.count})`;
            return(
                <Field key={value.name} className={`value ${value.className} no-wrap`} onChange={this.handleClick.bind(this, value.name)}
                       name={value.name} component={InputField}
                       type="checkbox" checked={value.checked} title={valueText}>{valueText}</Field>
            );
        };

        const noneChecked = () => {
            const checked = _.reduce(filterList, (checked, value) => checked || value.checked, false);
            return !checked;
        };

        return (
            <div className={classNames("filter-widget", {fixed})} ref={this.setWrapperRef.bind(this)}>
                <div className="filters-list">
                    {buildFieldElement(all)}
                    {filterList.map(value => {
                        return buildFieldElement(value);
                    })}
                </div>
                <button className="filter-button" disabled={noneChecked()} onClick={this.apply.bind(this)}>Apply</button>
            </div>
        );
    }
}

