import React from 'react';
import Isvg from 'react-inlinesvg';
import classNames from 'classnames';
import {parse} from 'query-string';
import _ from 'lodash';
import {openDialog} from "../dialog/Dialog";
import CloseWizardDialog from "./CloseWizardDialog";
import {routesObject} from "../../actions";


require('./wizardsHeader.scss');


const HeaderStep = ({stepNum, stepName, currentStepIndex}) => {
    const stepIndex = parseInt(stepNum);
    const passed = stepIndex < currentStepIndex;
    return (
        <div className={classNames('header-step', {
            active: currentStepIndex === stepIndex,
            passed: stepIndex < currentStepIndex
        })}>
            {!passed && <Isvg src={require(`./../../assets/svgs/step-${stepNum + 1}.svg`)}></Isvg>}
            {passed && <Isvg src={require('./../../assets/svgs/step-passed.svg')}></Isvg>}
            <div className="step-name">{stepName}</div>
        </div>
    );
};

const headerWithSteps = ["Tiering Setup", "Tier Volumes"];
const noSteps = [];
const wizardTypeToStepName = {
    setup: "Tiering Setup",
    'setup-azure': "Tiering Setup",
    'setup-sg': "Tiering Setup",
    'tier-volumes': "Tier Volumes",
    'manage-aggregates': "Manage Aggregates",
};
const typeOfHeaderByOrigin = (origin, wizardType) => {
    switch (origin) {
        case "setupCluster":
            return headerWithSteps;
        case "occm":
        case "dashboard":
        case "moreInfo":
            return wizardType === 'tier-volumes' || wizardType === 'manage-aggregates' ? noSteps : headerWithSteps;
        default:
            return null;
    }
};

export default (props) => {
    const {data: {wizardType}, location: {pathname}, cameFrom} = props;
    const origin = _.get(parse(window.location.search), "origin");
    const header = typeOfHeaderByOrigin(origin, wizardType);
    const currentStepName = wizardTypeToStepName[wizardType];
    const currentStepIndex = header.indexOf(currentStepName);

    const closeWizard = (el) => {
        const shouldOpenDialog = !pathname.includes('setup-complete') && header.length > 0; //in case of volumes only header will be empty and we don't want to open the dialog
        if (shouldOpenDialog)
            openDialog(<CloseWizardDialog className="close-wizard-dialog" discardWizard={discardWizard} {...props}
                                          currentStepName={currentStepName}/>, el.target);
        else discardWizard(cameFrom);
    }

    return (
        <header className="wizards-header">
            <div className="logo">
                <Isvg  src={require("./../../assets/svgs/tiering-icon.svg")}/>
                <span className="logo-text">Cloud Tiering</span>
            </div>
            <div className="steps">
                {header.map((step, index) => {
                    return <HeaderStep key={step} stepNum={index} stepName={step} currentStepIndex={currentStepIndex}/>
                })}
            </div>
            <div className="wizards-header-right-side">
                <button className="close" onClick={closeWizard}><Isvg
                    src={require('./../../assets/svgs/x.svg')}></Isvg></button>
            </div>
        </header>
    );
};

const discardWizard = (cameFrom) => {
    routesObject.routes.push(cameFrom ? cameFrom : '/clusters');
};