import React from 'react';
import { withRouter } from 'react-router-dom';
import { graphql } from '@apollo/client/react/hoc';
import _ from 'lodash';
import { connect } from 'react-redux';
import { GET_CLUSTER_QUERY } from '../graphql/queries';
import { ERROR_SERVER_ERROR, GENERAL_ERROR} from '../actions';
import LoadingIcon from '../components/widgets/LoadingIcon';

const OCCMIntegrationEntryPoint = (props) => {
        const { data: {entryType} } = props;
            if (props.getClusterQuery) {
                const { getClusterQuery: { loading, error, cluster } } = props;
                if (loading && !error) {
                    return (<LoadingIcon/>);
                }

                if (error) {
                    props.dispatch({
                        type: GENERAL_ERROR,
                        code: ERROR_SERVER_ERROR,
                        payload: error
                    });
                    console.log(`%c OCCM Entry Point got error on GetCluster ${JSON.stringify(error, null, 2)}`, 'font-weight:bold; color:red');
                }
                if (cluster) {
                    const { clusterId, name, agentCloudProvider, agentId } = cluster;
                    if (entryType === 'setup') {
                        if (agentCloudProvider !== 'AZURE') {
                            const fixedProvider = agentCloudProvider === 'ONPREM' ? 'AWS' : agentCloudProvider;
                            props.history.push(`/setup/${clusterId}/${name}/${agentId}/${fixedProvider}/setup-bucket?origin=occm`);
                        } else {
                            props.history.push(`/setup-azure/${clusterId}/${name}/${agentId}/${agentCloudProvider}/resource-group?origin=occm`);
                        }
                    }
                    else if (entryType === 'tier') {
                        props.history.push(`/tier-volumes/${clusterId}/${name}/volumes?origin=occm`)
                    }
                }
            } else {
                props.history.push('/clusters');
            }

        return <div></div>;
}

const mapStateToProps = (state) => {
    return {
        routingInfo: state.appRouting.routingInfo,
        agentId: state.general.agentId,
        accountId: state.general.accountId,
        workspaceId: state.general.workspaceId,
    };
};

export default _.flowRight(
    connect(mapStateToProps),
    withRouter,
    graphql(GET_CLUSTER_QUERY, {
        name: 'getClusterQuery',
        skip: props => {
            const clusterId = props.match.params.clusterId;
            return !clusterId;
        },
        options: (props) => {
            const clusterId = props.match.params.clusterId;
            return {
                variables: {
                    clusterId,
                    accountId: props.accountId,
                    agentId: props.agentId,
                    workspaceId: props.workspaceId
                },
                fetchPolicy: "cache-first"
            };
        }
    })
)(OCCMIntegrationEntryPoint);